# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'ServiceGroupMonitoringAgentProcessAlertConfigArgs',
    'ServiceGroupMonitoringAgentProcessAlertConfigArgsDict',
    'ServiceGroupMonitoringAgentProcessAlertConfigTargetListArgs',
    'ServiceGroupMonitoringAgentProcessAlertConfigTargetListArgsDict',
    'ServiceGroupMonitoringAgentProcessMatchExpressArgs',
    'ServiceGroupMonitoringAgentProcessMatchExpressArgsDict',
]

MYPY = False

if not MYPY:
    class ServiceGroupMonitoringAgentProcessAlertConfigArgsDict(TypedDict):
        comparison_operator: pulumi.Input[str]
        """
        The operator that is used to compare the metric value with the threshold. Valid values: `GreaterThanOrEqualToThreshold`, `GreaterThanThreshold`, `LessThanOrEqualToThreshold`, `LessThanThreshold`, `NotEqualToThreshold`, `GreaterThanYesterday`, `LessThanYesterday`, `GreaterThanLastWeek`, `LessThanLastWeek`, `GreaterThanLastPeriod`, `LessThanLastPeriod`.
        """
        escalations_level: pulumi.Input[str]
        """
        The alert level. Valid values: `critical`, `warn`, `info`.
        """
        statistics: pulumi.Input[str]
        """
        The statistical method for alerts. Valid values: `Average`.
        """
        threshold: pulumi.Input[str]
        """
        The alert threshold.
        """
        times: pulumi.Input[str]
        """
        The number of times for which the threshold can be consecutively exceeded.
        """
        effective_interval: NotRequired[pulumi.Input[str]]
        """
        The time period during which the alert rule is effective.
        """
        silence_time: NotRequired[pulumi.Input[int]]
        """
        The mute period during which new alert notifications are not sent even if the trigger conditions are met. Unit: seconds.
        """
        target_lists: NotRequired[pulumi.Input[Sequence[pulumi.Input['ServiceGroupMonitoringAgentProcessAlertConfigTargetListArgsDict']]]]
        """
        The alert triggers. See `target_list` below.
        """
        webhook: NotRequired[pulumi.Input[str]]
        """
        The callback URL.
        """
elif False:
    ServiceGroupMonitoringAgentProcessAlertConfigArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class ServiceGroupMonitoringAgentProcessAlertConfigArgs:
    def __init__(__self__, *,
                 comparison_operator: pulumi.Input[str],
                 escalations_level: pulumi.Input[str],
                 statistics: pulumi.Input[str],
                 threshold: pulumi.Input[str],
                 times: pulumi.Input[str],
                 effective_interval: Optional[pulumi.Input[str]] = None,
                 silence_time: Optional[pulumi.Input[int]] = None,
                 target_lists: Optional[pulumi.Input[Sequence[pulumi.Input['ServiceGroupMonitoringAgentProcessAlertConfigTargetListArgs']]]] = None,
                 webhook: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[str] comparison_operator: The operator that is used to compare the metric value with the threshold. Valid values: `GreaterThanOrEqualToThreshold`, `GreaterThanThreshold`, `LessThanOrEqualToThreshold`, `LessThanThreshold`, `NotEqualToThreshold`, `GreaterThanYesterday`, `LessThanYesterday`, `GreaterThanLastWeek`, `LessThanLastWeek`, `GreaterThanLastPeriod`, `LessThanLastPeriod`.
        :param pulumi.Input[str] escalations_level: The alert level. Valid values: `critical`, `warn`, `info`.
        :param pulumi.Input[str] statistics: The statistical method for alerts. Valid values: `Average`.
        :param pulumi.Input[str] threshold: The alert threshold.
        :param pulumi.Input[str] times: The number of times for which the threshold can be consecutively exceeded.
        :param pulumi.Input[str] effective_interval: The time period during which the alert rule is effective.
        :param pulumi.Input[int] silence_time: The mute period during which new alert notifications are not sent even if the trigger conditions are met. Unit: seconds.
        :param pulumi.Input[Sequence[pulumi.Input['ServiceGroupMonitoringAgentProcessAlertConfigTargetListArgs']]] target_lists: The alert triggers. See `target_list` below.
        :param pulumi.Input[str] webhook: The callback URL.
        """
        pulumi.set(__self__, "comparison_operator", comparison_operator)
        pulumi.set(__self__, "escalations_level", escalations_level)
        pulumi.set(__self__, "statistics", statistics)
        pulumi.set(__self__, "threshold", threshold)
        pulumi.set(__self__, "times", times)
        if effective_interval is not None:
            pulumi.set(__self__, "effective_interval", effective_interval)
        if silence_time is not None:
            pulumi.set(__self__, "silence_time", silence_time)
        if target_lists is not None:
            pulumi.set(__self__, "target_lists", target_lists)
        if webhook is not None:
            pulumi.set(__self__, "webhook", webhook)

    @property
    @pulumi.getter(name="comparisonOperator")
    def comparison_operator(self) -> pulumi.Input[str]:
        """
        The operator that is used to compare the metric value with the threshold. Valid values: `GreaterThanOrEqualToThreshold`, `GreaterThanThreshold`, `LessThanOrEqualToThreshold`, `LessThanThreshold`, `NotEqualToThreshold`, `GreaterThanYesterday`, `LessThanYesterday`, `GreaterThanLastWeek`, `LessThanLastWeek`, `GreaterThanLastPeriod`, `LessThanLastPeriod`.
        """
        return pulumi.get(self, "comparison_operator")

    @comparison_operator.setter
    def comparison_operator(self, value: pulumi.Input[str]):
        pulumi.set(self, "comparison_operator", value)

    @property
    @pulumi.getter(name="escalationsLevel")
    def escalations_level(self) -> pulumi.Input[str]:
        """
        The alert level. Valid values: `critical`, `warn`, `info`.
        """
        return pulumi.get(self, "escalations_level")

    @escalations_level.setter
    def escalations_level(self, value: pulumi.Input[str]):
        pulumi.set(self, "escalations_level", value)

    @property
    @pulumi.getter
    def statistics(self) -> pulumi.Input[str]:
        """
        The statistical method for alerts. Valid values: `Average`.
        """
        return pulumi.get(self, "statistics")

    @statistics.setter
    def statistics(self, value: pulumi.Input[str]):
        pulumi.set(self, "statistics", value)

    @property
    @pulumi.getter
    def threshold(self) -> pulumi.Input[str]:
        """
        The alert threshold.
        """
        return pulumi.get(self, "threshold")

    @threshold.setter
    def threshold(self, value: pulumi.Input[str]):
        pulumi.set(self, "threshold", value)

    @property
    @pulumi.getter
    def times(self) -> pulumi.Input[str]:
        """
        The number of times for which the threshold can be consecutively exceeded.
        """
        return pulumi.get(self, "times")

    @times.setter
    def times(self, value: pulumi.Input[str]):
        pulumi.set(self, "times", value)

    @property
    @pulumi.getter(name="effectiveInterval")
    def effective_interval(self) -> Optional[pulumi.Input[str]]:
        """
        The time period during which the alert rule is effective.
        """
        return pulumi.get(self, "effective_interval")

    @effective_interval.setter
    def effective_interval(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "effective_interval", value)

    @property
    @pulumi.getter(name="silenceTime")
    def silence_time(self) -> Optional[pulumi.Input[int]]:
        """
        The mute period during which new alert notifications are not sent even if the trigger conditions are met. Unit: seconds.
        """
        return pulumi.get(self, "silence_time")

    @silence_time.setter
    def silence_time(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "silence_time", value)

    @property
    @pulumi.getter(name="targetLists")
    def target_lists(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ServiceGroupMonitoringAgentProcessAlertConfigTargetListArgs']]]]:
        """
        The alert triggers. See `target_list` below.
        """
        return pulumi.get(self, "target_lists")

    @target_lists.setter
    def target_lists(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ServiceGroupMonitoringAgentProcessAlertConfigTargetListArgs']]]]):
        pulumi.set(self, "target_lists", value)

    @property
    @pulumi.getter
    def webhook(self) -> Optional[pulumi.Input[str]]:
        """
        The callback URL.
        """
        return pulumi.get(self, "webhook")

    @webhook.setter
    def webhook(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "webhook", value)


if not MYPY:
    class ServiceGroupMonitoringAgentProcessAlertConfigTargetListArgsDict(TypedDict):
        arn: NotRequired[pulumi.Input[str]]
        """
        The Alibaba Cloud Resource Name (ARN) of the resource.
        """
        json_params: NotRequired[pulumi.Input[str]]
        """
        The parameters of the alert callback. Specify the parameters in the JSON format.
        """
        level: NotRequired[pulumi.Input[str]]
        """
        The alert level. Valid values: `CRITICAL`, `WARN`, `INFO`.
        """
        target_list_id: NotRequired[pulumi.Input[str]]
        """
        The ID of the resource for which alerts are triggered.
        """
elif False:
    ServiceGroupMonitoringAgentProcessAlertConfigTargetListArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class ServiceGroupMonitoringAgentProcessAlertConfigTargetListArgs:
    def __init__(__self__, *,
                 arn: Optional[pulumi.Input[str]] = None,
                 json_params: Optional[pulumi.Input[str]] = None,
                 level: Optional[pulumi.Input[str]] = None,
                 target_list_id: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[str] arn: The Alibaba Cloud Resource Name (ARN) of the resource.
        :param pulumi.Input[str] json_params: The parameters of the alert callback. Specify the parameters in the JSON format.
        :param pulumi.Input[str] level: The alert level. Valid values: `CRITICAL`, `WARN`, `INFO`.
        :param pulumi.Input[str] target_list_id: The ID of the resource for which alerts are triggered.
        """
        if arn is not None:
            pulumi.set(__self__, "arn", arn)
        if json_params is not None:
            pulumi.set(__self__, "json_params", json_params)
        if level is not None:
            pulumi.set(__self__, "level", level)
        if target_list_id is not None:
            pulumi.set(__self__, "target_list_id", target_list_id)

    @property
    @pulumi.getter
    def arn(self) -> Optional[pulumi.Input[str]]:
        """
        The Alibaba Cloud Resource Name (ARN) of the resource.
        """
        return pulumi.get(self, "arn")

    @arn.setter
    def arn(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "arn", value)

    @property
    @pulumi.getter(name="jsonParams")
    def json_params(self) -> Optional[pulumi.Input[str]]:
        """
        The parameters of the alert callback. Specify the parameters in the JSON format.
        """
        return pulumi.get(self, "json_params")

    @json_params.setter
    def json_params(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "json_params", value)

    @property
    @pulumi.getter
    def level(self) -> Optional[pulumi.Input[str]]:
        """
        The alert level. Valid values: `CRITICAL`, `WARN`, `INFO`.
        """
        return pulumi.get(self, "level")

    @level.setter
    def level(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "level", value)

    @property
    @pulumi.getter(name="targetListId")
    def target_list_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the resource for which alerts are triggered.
        """
        return pulumi.get(self, "target_list_id")

    @target_list_id.setter
    def target_list_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "target_list_id", value)


if not MYPY:
    class ServiceGroupMonitoringAgentProcessMatchExpressArgsDict(TypedDict):
        function: NotRequired[pulumi.Input[str]]
        """
        The matching condition. Valid values: `all`, `startWith`, `endWith`, `contains`, `notContains`, `equals`.
        """
        name: NotRequired[pulumi.Input[str]]
        """
        The criteria based on which the instances are matched.
        """
        value: NotRequired[pulumi.Input[str]]
        """
        The keyword used to match the instance name.
        """
elif False:
    ServiceGroupMonitoringAgentProcessMatchExpressArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class ServiceGroupMonitoringAgentProcessMatchExpressArgs:
    def __init__(__self__, *,
                 function: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 value: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[str] function: The matching condition. Valid values: `all`, `startWith`, `endWith`, `contains`, `notContains`, `equals`.
        :param pulumi.Input[str] name: The criteria based on which the instances are matched.
        :param pulumi.Input[str] value: The keyword used to match the instance name.
        """
        if function is not None:
            pulumi.set(__self__, "function", function)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def function(self) -> Optional[pulumi.Input[str]]:
        """
        The matching condition. Valid values: `all`, `startWith`, `endWith`, `contains`, `notContains`, `equals`.
        """
        return pulumi.get(self, "function")

    @function.setter
    def function(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "function", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The criteria based on which the instances are matched.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def value(self) -> Optional[pulumi.Input[str]]:
        """
        The keyword used to match the instance name.
        """
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "value", value)





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'ClusterNetworkArgs',
    'ClusterNetworkArgsDict',
]

MYPY = False

if not MYPY:
    class ClusterNetworkArgsDict(TypedDict):
        vpc_id: pulumi.Input[str]
        """
        VpcId to which the cluster belongs.
        """
        vswitches: pulumi.Input[Sequence[pulumi.Input[str]]]
        """
        Switch to which the cluster belongs.
        """
        security_group_ids: NotRequired[pulumi.Input[Sequence[pulumi.Input[str]]]]
        """
        Security group to which the cluster belongs.
        """
elif False:
    ClusterNetworkArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class ClusterNetworkArgs:
    def __init__(__self__, *,
                 vpc_id: pulumi.Input[str],
                 vswitches: pulumi.Input[Sequence[pulumi.Input[str]]],
                 security_group_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None):
        """
        :param pulumi.Input[str] vpc_id: VpcId to which the cluster belongs.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] vswitches: Switch to which the cluster belongs.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] security_group_ids: Security group to which the cluster belongs.
        """
        pulumi.set(__self__, "vpc_id", vpc_id)
        pulumi.set(__self__, "vswitches", vswitches)
        if security_group_ids is not None:
            pulumi.set(__self__, "security_group_ids", security_group_ids)

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> pulumi.Input[str]:
        """
        VpcId to which the cluster belongs.
        """
        return pulumi.get(self, "vpc_id")

    @vpc_id.setter
    def vpc_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "vpc_id", value)

    @property
    @pulumi.getter
    def vswitches(self) -> pulumi.Input[Sequence[pulumi.Input[str]]]:
        """
        Switch to which the cluster belongs.
        """
        return pulumi.get(self, "vswitches")

    @vswitches.setter
    def vswitches(self, value: pulumi.Input[Sequence[pulumi.Input[str]]]):
        pulumi.set(self, "vswitches", value)

    @property
    @pulumi.getter(name="securityGroupIds")
    def security_group_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        Security group to which the cluster belongs.
        """
        return pulumi.get(self, "security_group_ids")

    @security_group_ids.setter
    def security_group_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "security_group_ids", value)





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'VvpInstanceResourceSpecArgs',
    'VvpInstanceResourceSpecArgsDict',
    'VvpInstanceStorageArgs',
    'VvpInstanceStorageArgsDict',
    'VvpInstanceStorageOssArgs',
    'VvpInstanceStorageOssArgsDict',
]

MYPY = False

if not MYPY:
    class VvpInstanceResourceSpecArgsDict(TypedDict):
        cpu: NotRequired[pulumi.Input[int]]
        """
        CPU number.
        """
        memory_gb: NotRequired[pulumi.Input[int]]
        """
        Memory size.
        """
elif False:
    VvpInstanceResourceSpecArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class VvpInstanceResourceSpecArgs:
    def __init__(__self__, *,
                 cpu: Optional[pulumi.Input[int]] = None,
                 memory_gb: Optional[pulumi.Input[int]] = None):
        """
        :param pulumi.Input[int] cpu: CPU number.
        :param pulumi.Input[int] memory_gb: Memory size.
        """
        if cpu is not None:
            pulumi.set(__self__, "cpu", cpu)
        if memory_gb is not None:
            pulumi.set(__self__, "memory_gb", memory_gb)

    @property
    @pulumi.getter
    def cpu(self) -> Optional[pulumi.Input[int]]:
        """
        CPU number.
        """
        return pulumi.get(self, "cpu")

    @cpu.setter
    def cpu(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "cpu", value)

    @property
    @pulumi.getter(name="memoryGb")
    def memory_gb(self) -> Optional[pulumi.Input[int]]:
        """
        Memory size.
        """
        return pulumi.get(self, "memory_gb")

    @memory_gb.setter
    def memory_gb(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "memory_gb", value)


if not MYPY:
    class VvpInstanceStorageArgsDict(TypedDict):
        oss: pulumi.Input['VvpInstanceStorageOssArgsDict']
        """
        OSS stores information. See `oss` below.
        """
elif False:
    VvpInstanceStorageArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class VvpInstanceStorageArgs:
    def __init__(__self__, *,
                 oss: pulumi.Input['VvpInstanceStorageOssArgs']):
        """
        :param pulumi.Input['VvpInstanceStorageOssArgs'] oss: OSS stores information. See `oss` below.
        """
        pulumi.set(__self__, "oss", oss)

    @property
    @pulumi.getter
    def oss(self) -> pulumi.Input['VvpInstanceStorageOssArgs']:
        """
        OSS stores information. See `oss` below.
        """
        return pulumi.get(self, "oss")

    @oss.setter
    def oss(self, value: pulumi.Input['VvpInstanceStorageOssArgs']):
        pulumi.set(self, "oss", value)


if not MYPY:
    class VvpInstanceStorageOssArgsDict(TypedDict):
        bucket: pulumi.Input[str]
        """
        OSS Bucket name.
        """
elif False:
    VvpInstanceStorageOssArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class VvpInstanceStorageOssArgs:
    def __init__(__self__, *,
                 bucket: pulumi.Input[str]):
        """
        :param pulumi.Input[str] bucket: OSS Bucket name.
        """
        pulumi.set(__self__, "bucket", bucket)

    @property
    @pulumi.getter
    def bucket(self) -> pulumi.Input[str]:
        """
        OSS Bucket name.
        """
        return pulumi.get(self, "bucket")

    @bucket.setter
    def bucket(self, value: pulumi.Input[str]):
        pulumi.set(self, "bucket", value)





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'InstanceEcsList',
    'GetAutoSnapShotPoliciesAutoSnapShotPolicyResult',
    'GetInstancesInstanceResult',
    'GetInstancesInstanceEcsListResult',
    'GetSnapshotsSnapshotResult',
]

@pulumi.output_type
class InstanceEcsList(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "ecsId":
            suggest = "ecs_id"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in InstanceEcsList. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        InstanceEcsList.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        InstanceEcsList.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 ecs_id: Optional[str] = None):
        """
        :param str ecs_id: The ID of the ECS instance.
        """
        if ecs_id is not None:
            pulumi.set(__self__, "ecs_id", ecs_id)

    @property
    @pulumi.getter(name="ecsId")
    def ecs_id(self) -> Optional[str]:
        """
        The ID of the ECS instance.
        """
        return pulumi.get(self, "ecs_id")


@pulumi.output_type
class GetAutoSnapShotPoliciesAutoSnapShotPolicyResult(dict):
    def __init__(__self__, *,
                 applied_dbfs_number: int,
                 create_time: str,
                 id: str,
                 last_modified: str,
                 policy_id: str,
                 policy_name: str,
                 repeat_weekdays: Sequence[str],
                 retention_days: int,
                 status: str,
                 status_detail: str,
                 time_points: Sequence[str]):
        """
        :param int applied_dbfs_number: The number of database file systems set by the automatic snapshot policy.
        :param str create_time: The creation time of the resource
        :param str id: The ID of the policy.
        :param str last_modified: Last modification time of automatic snapshot policy
        :param str policy_id: Automatic snapshot policy ID
        :param str policy_name: Automatic snapshot policy name
        :param Sequence[str] repeat_weekdays: A collection of automatic snapshots performed on several days of the week.
        :param int retention_days: Automatic snapshot retention days
        :param str status: Automatic snapshot policy status
        :param str status_detail: Automatic snapshot policy status details
        :param Sequence[str] time_points: The set of times at which the snapshot is taken on the day the automatic snapshot is executed.
        """
        pulumi.set(__self__, "applied_dbfs_number", applied_dbfs_number)
        pulumi.set(__self__, "create_time", create_time)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "last_modified", last_modified)
        pulumi.set(__self__, "policy_id", policy_id)
        pulumi.set(__self__, "policy_name", policy_name)
        pulumi.set(__self__, "repeat_weekdays", repeat_weekdays)
        pulumi.set(__self__, "retention_days", retention_days)
        pulumi.set(__self__, "status", status)
        pulumi.set(__self__, "status_detail", status_detail)
        pulumi.set(__self__, "time_points", time_points)

    @property
    @pulumi.getter(name="appliedDbfsNumber")
    def applied_dbfs_number(self) -> int:
        """
        The number of database file systems set by the automatic snapshot policy.
        """
        return pulumi.get(self, "applied_dbfs_number")

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> str:
        """
        The creation time of the resource
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The ID of the policy.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="lastModified")
    def last_modified(self) -> str:
        """
        Last modification time of automatic snapshot policy
        """
        return pulumi.get(self, "last_modified")

    @property
    @pulumi.getter(name="policyId")
    def policy_id(self) -> str:
        """
        Automatic snapshot policy ID
        """
        return pulumi.get(self, "policy_id")

    @property
    @pulumi.getter(name="policyName")
    def policy_name(self) -> str:
        """
        Automatic snapshot policy name
        """
        return pulumi.get(self, "policy_name")

    @property
    @pulumi.getter(name="repeatWeekdays")
    def repeat_weekdays(self) -> Sequence[str]:
        """
        A collection of automatic snapshots performed on several days of the week.
        """
        return pulumi.get(self, "repeat_weekdays")

    @property
    @pulumi.getter(name="retentionDays")
    def retention_days(self) -> int:
        """
        Automatic snapshot retention days
        """
        return pulumi.get(self, "retention_days")

    @property
    @pulumi.getter
    def status(self) -> str:
        """
        Automatic snapshot policy status
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="statusDetail")
    def status_detail(self) -> str:
        """
        Automatic snapshot policy status details
        """
        return pulumi.get(self, "status_detail")

    @property
    @pulumi.getter(name="timePoints")
    def time_points(self) -> Sequence[str]:
        """
        The set of times at which the snapshot is taken on the day the automatic snapshot is executed.
        """
        return pulumi.get(self, "time_points")


@pulumi.output_type
class GetInstancesInstanceResult(dict):
    def __init__(__self__, *,
                 attach_node_number: int,
                 category: str,
                 create_time: str,
                 dbfs_cluster_id: str,
                 ecs_lists: Sequence['outputs.GetInstancesInstanceEcsListResult'],
                 enable_raid: bool,
                 encryption: bool,
                 id: str,
                 instance_id: str,
                 instance_name: str,
                 kms_key_id: str,
                 payment_type: str,
                 performance_level: str,
                 raid_stripe_unit_number: str,
                 size: int,
                 status: str,
                 zone_id: str):
        """
        :param int attach_node_number: the number of nodes of the Database file system.
        :param str category: The type of the Database file system. Valid values: `standard`.
        :param str create_time: The create time of the Database file system.
        :param str dbfs_cluster_id: The cluster ID of the Database file system.
        :param Sequence['GetInstancesInstanceEcsListArgs'] ecs_lists: The collection of ECS instances mounted to the Database file system.
        :param bool enable_raid: Whether to create the Database file system in RAID way. Valid values : `true` anf `false`.
        :param bool encryption: Whether to encrypt the Database file system. Valid values: `true` and `false`.
        :param str id: The ID of the Instance.
        :param str instance_id: The ID of the Database File System
        :param str instance_name: The name of the Database file system.
        :param str kms_key_id: The KMS key ID of the Database file system used. This parameter is valid When `encryption` parameter is set to `true`.
        :param str payment_type: Thr payment type of the Database file system. Valid value: `PayAsYouGo`.
        :param str performance_level: The performance level of the Database file system. Valid values: `PL0`, `PL1`, `PL2`, `PL3`.
        :param str raid_stripe_unit_number: The number of strip . When `enable_raid` parameter is set to `true` will transfer. This parameter is valid When `enable_raid` parameter is set to `true`.
        :param int size: The size Of the Database file system. Unit: GiB.
        :param str status: The status of the Database file system.
        :param str zone_id: The Zone ID of the Database file system.
        """
        pulumi.set(__self__, "attach_node_number", attach_node_number)
        pulumi.set(__self__, "category", category)
        pulumi.set(__self__, "create_time", create_time)
        pulumi.set(__self__, "dbfs_cluster_id", dbfs_cluster_id)
        pulumi.set(__self__, "ecs_lists", ecs_lists)
        pulumi.set(__self__, "enable_raid", enable_raid)
        pulumi.set(__self__, "encryption", encryption)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "instance_id", instance_id)
        pulumi.set(__self__, "instance_name", instance_name)
        pulumi.set(__self__, "kms_key_id", kms_key_id)
        pulumi.set(__self__, "payment_type", payment_type)
        pulumi.set(__self__, "performance_level", performance_level)
        pulumi.set(__self__, "raid_stripe_unit_number", raid_stripe_unit_number)
        pulumi.set(__self__, "size", size)
        pulumi.set(__self__, "status", status)
        pulumi.set(__self__, "zone_id", zone_id)

    @property
    @pulumi.getter(name="attachNodeNumber")
    def attach_node_number(self) -> int:
        """
        the number of nodes of the Database file system.
        """
        return pulumi.get(self, "attach_node_number")

    @property
    @pulumi.getter
    def category(self) -> str:
        """
        The type of the Database file system. Valid values: `standard`.
        """
        return pulumi.get(self, "category")

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> str:
        """
        The create time of the Database file system.
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter(name="dbfsClusterId")
    def dbfs_cluster_id(self) -> str:
        """
        The cluster ID of the Database file system.
        """
        return pulumi.get(self, "dbfs_cluster_id")

    @property
    @pulumi.getter(name="ecsLists")
    def ecs_lists(self) -> Sequence['outputs.GetInstancesInstanceEcsListResult']:
        """
        The collection of ECS instances mounted to the Database file system.
        """
        return pulumi.get(self, "ecs_lists")

    @property
    @pulumi.getter(name="enableRaid")
    def enable_raid(self) -> bool:
        """
        Whether to create the Database file system in RAID way. Valid values : `true` anf `false`.
        """
        return pulumi.get(self, "enable_raid")

    @property
    @pulumi.getter
    def encryption(self) -> bool:
        """
        Whether to encrypt the Database file system. Valid values: `true` and `false`.
        """
        return pulumi.get(self, "encryption")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The ID of the Instance.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> str:
        """
        The ID of the Database File System
        """
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter(name="instanceName")
    def instance_name(self) -> str:
        """
        The name of the Database file system.
        """
        return pulumi.get(self, "instance_name")

    @property
    @pulumi.getter(name="kmsKeyId")
    def kms_key_id(self) -> str:
        """
        The KMS key ID of the Database file system used. This parameter is valid When `encryption` parameter is set to `true`.
        """
        return pulumi.get(self, "kms_key_id")

    @property
    @pulumi.getter(name="paymentType")
    def payment_type(self) -> str:
        """
        Thr payment type of the Database file system. Valid value: `PayAsYouGo`.
        """
        return pulumi.get(self, "payment_type")

    @property
    @pulumi.getter(name="performanceLevel")
    def performance_level(self) -> str:
        """
        The performance level of the Database file system. Valid values: `PL0`, `PL1`, `PL2`, `PL3`.
        """
        return pulumi.get(self, "performance_level")

    @property
    @pulumi.getter(name="raidStripeUnitNumber")
    def raid_stripe_unit_number(self) -> str:
        """
        The number of strip . When `enable_raid` parameter is set to `true` will transfer. This parameter is valid When `enable_raid` parameter is set to `true`.
        """
        return pulumi.get(self, "raid_stripe_unit_number")

    @property
    @pulumi.getter
    def size(self) -> int:
        """
        The size Of the Database file system. Unit: GiB.
        """
        return pulumi.get(self, "size")

    @property
    @pulumi.getter
    def status(self) -> str:
        """
        The status of the Database file system.
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="zoneId")
    def zone_id(self) -> str:
        """
        The Zone ID of the Database file system.
        """
        return pulumi.get(self, "zone_id")


@pulumi.output_type
class GetInstancesInstanceEcsListResult(dict):
    def __init__(__self__, *,
                 ecs_id: str):
        """
        :param str ecs_id: The ID of the ECS instance.
        """
        pulumi.set(__self__, "ecs_id", ecs_id)

    @property
    @pulumi.getter(name="ecsId")
    def ecs_id(self) -> str:
        """
        The ID of the ECS instance.
        """
        return pulumi.get(self, "ecs_id")


@pulumi.output_type
class GetSnapshotsSnapshotResult(dict):
    def __init__(__self__, *,
                 category: str,
                 create_time: str,
                 description: str,
                 id: str,
                 instance_id: str,
                 last_modified_time: str,
                 progress: str,
                 remain_time: int,
                 retention_days: int,
                 snapshot_id: str,
                 snapshot_name: str,
                 snapshot_type: str,
                 source_fs_size: int,
                 status: str):
        """
        :param str category: The type of the Snapshot.
        :param str create_time: The creation time of the snapshot.
        :param str description: The description of the snapshot.
        :param str id: The ID of the Snapshot.
        :param str instance_id: The ID of the database file system.
        :param str last_modified_time: The last modification time of the snapshot.
        :param str progress: The progress of the snapshot.
        :param int remain_time: The remaining completion time of the snapshot being created, in seconds.
        :param int retention_days: The retention days of the snapshot.
        :param str snapshot_id: The ID of the snapshot.
        :param str snapshot_name: The name of the snapshot.
        :param str snapshot_type: The creation of the snapshot.
        :param int source_fs_size: Source database file system capacity.
        :param str status: The status of the snapshot. Possible values: `progressing`, `accomplished`, `failed`.
        """
        pulumi.set(__self__, "category", category)
        pulumi.set(__self__, "create_time", create_time)
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "instance_id", instance_id)
        pulumi.set(__self__, "last_modified_time", last_modified_time)
        pulumi.set(__self__, "progress", progress)
        pulumi.set(__self__, "remain_time", remain_time)
        pulumi.set(__self__, "retention_days", retention_days)
        pulumi.set(__self__, "snapshot_id", snapshot_id)
        pulumi.set(__self__, "snapshot_name", snapshot_name)
        pulumi.set(__self__, "snapshot_type", snapshot_type)
        pulumi.set(__self__, "source_fs_size", source_fs_size)
        pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter
    def category(self) -> str:
        """
        The type of the Snapshot.
        """
        return pulumi.get(self, "category")

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> str:
        """
        The creation time of the snapshot.
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter
    def description(self) -> str:
        """
        The description of the snapshot.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The ID of the Snapshot.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> str:
        """
        The ID of the database file system.
        """
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter(name="lastModifiedTime")
    def last_modified_time(self) -> str:
        """
        The last modification time of the snapshot.
        """
        return pulumi.get(self, "last_modified_time")

    @property
    @pulumi.getter
    def progress(self) -> str:
        """
        The progress of the snapshot.
        """
        return pulumi.get(self, "progress")

    @property
    @pulumi.getter(name="remainTime")
    def remain_time(self) -> int:
        """
        The remaining completion time of the snapshot being created, in seconds.
        """
        return pulumi.get(self, "remain_time")

    @property
    @pulumi.getter(name="retentionDays")
    def retention_days(self) -> int:
        """
        The retention days of the snapshot.
        """
        return pulumi.get(self, "retention_days")

    @property
    @pulumi.getter(name="snapshotId")
    def snapshot_id(self) -> str:
        """
        The ID of the snapshot.
        """
        return pulumi.get(self, "snapshot_id")

    @property
    @pulumi.getter(name="snapshotName")
    def snapshot_name(self) -> str:
        """
        The name of the snapshot.
        """
        return pulumi.get(self, "snapshot_name")

    @property
    @pulumi.getter(name="snapshotType")
    def snapshot_type(self) -> str:
        """
        The creation of the snapshot.
        """
        return pulumi.get(self, "snapshot_type")

    @property
    @pulumi.getter(name="sourceFsSize")
    def source_fs_size(self) -> int:
        """
        Source database file system capacity.
        """
        return pulumi.get(self, "source_fs_size")

    @property
    @pulumi.getter
    def status(self) -> str:
        """
        The status of the snapshot. Possible values: `progressing`, `accomplished`, `failed`.
        """
        return pulumi.get(self, "status")





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from .. import _utilities
import typing
# Export this package's modules as members:
from .application import *
from .application_scaling_rule import *
from .config_map import *
from .get_application_scaling_rules import *
from .get_applications import *
from .get_config_maps import *
from .get_grey_tag_routes import *
from .get_ingresses import *
from .get_instance_specifications import *
from .get_namespaces import *
from .get_service import *
from .grey_tag_route import *
from .ingress import *
from .load_balancer_internet import *
from .load_balancer_intranet import *
from .namespace import *
from ._inputs import *
from . import outputs



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetConfigsConfigResult',
    'GetDataLimitsLimitResult',
    'GetInstancesInstanceResult',
    'GetRulesRuleResult',
]

@pulumi.output_type
class GetConfigsConfigResult(dict):
    def __init__(__self__, *,
                 code: str,
                 config_id: str,
                 default_value: str,
                 description: str,
                 id: str,
                 value: str):
        """
        :param str code: Abnormal Alarm General Configuration Module by Using the Encoding.Valid values: `access_failed_cnt`, `access_permission_exprie_max_days`, `log_datasize_avg_days`.
        :param str config_id: Configure the Number.
        :param str default_value: Default Value.
        :param str description: Abnormal Alarm General Description of the Configuration Item.
        :param str id: The ID of the Config.
        :param str value: The Specified Exception Alarm Generic by Using the Value. Code Different Values for This Parameter the Specific Meaning of Different.
        """
        pulumi.set(__self__, "code", code)
        pulumi.set(__self__, "config_id", config_id)
        pulumi.set(__self__, "default_value", default_value)
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def code(self) -> str:
        """
        Abnormal Alarm General Configuration Module by Using the Encoding.Valid values: `access_failed_cnt`, `access_permission_exprie_max_days`, `log_datasize_avg_days`.
        """
        return pulumi.get(self, "code")

    @property
    @pulumi.getter(name="configId")
    def config_id(self) -> str:
        """
        Configure the Number.
        """
        return pulumi.get(self, "config_id")

    @property
    @pulumi.getter(name="defaultValue")
    def default_value(self) -> str:
        """
        Default Value.
        """
        return pulumi.get(self, "default_value")

    @property
    @pulumi.getter
    def description(self) -> str:
        """
        Abnormal Alarm General Description of the Configuration Item.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The ID of the Config.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def value(self) -> str:
        """
        The Specified Exception Alarm Generic by Using the Value. Code Different Values for This Parameter the Specific Meaning of Different.
        """
        return pulumi.get(self, "value")


@pulumi.output_type
class GetDataLimitsLimitResult(dict):
    def __init__(__self__, *,
                 audit_status: int,
                 check_status: int,
                 data_limit_id: str,
                 engine_type: str,
                 id: str,
                 local_name: str,
                 log_store_day: int,
                 parent_id: str,
                 port: int,
                 resource_type: str,
                 user_name: str):
        """
        :param int audit_status: Whether to enable the log auditing feature.
        :param int check_status: The status of the connectivity test between the data asset and SDDP.
        :param str data_limit_id: The first ID of the resource.
        :param str engine_type: The type of the database.
        :param str id: The ID of the Data Limit.
        :param str local_name: The name of the service to which the data asset belongs.
        :param int log_store_day: The retention period of raw logs after you enable the log auditing feature.
        :param str parent_id: The ID of the data asset.
        :param int port: The port that is used to connect to the database.
        :param str resource_type: The type of the service to which the data asset belongs.
        :param str user_name: The name of the user who owns the data asset.
        """
        pulumi.set(__self__, "audit_status", audit_status)
        pulumi.set(__self__, "check_status", check_status)
        pulumi.set(__self__, "data_limit_id", data_limit_id)
        pulumi.set(__self__, "engine_type", engine_type)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "local_name", local_name)
        pulumi.set(__self__, "log_store_day", log_store_day)
        pulumi.set(__self__, "parent_id", parent_id)
        pulumi.set(__self__, "port", port)
        pulumi.set(__self__, "resource_type", resource_type)
        pulumi.set(__self__, "user_name", user_name)

    @property
    @pulumi.getter(name="auditStatus")
    def audit_status(self) -> int:
        """
        Whether to enable the log auditing feature.
        """
        return pulumi.get(self, "audit_status")

    @property
    @pulumi.getter(name="checkStatus")
    def check_status(self) -> int:
        """
        The status of the connectivity test between the data asset and SDDP.
        """
        return pulumi.get(self, "check_status")

    @property
    @pulumi.getter(name="dataLimitId")
    def data_limit_id(self) -> str:
        """
        The first ID of the resource.
        """
        return pulumi.get(self, "data_limit_id")

    @property
    @pulumi.getter(name="engineType")
    def engine_type(self) -> str:
        """
        The type of the database.
        """
        return pulumi.get(self, "engine_type")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The ID of the Data Limit.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="localName")
    def local_name(self) -> str:
        """
        The name of the service to which the data asset belongs.
        """
        return pulumi.get(self, "local_name")

    @property
    @pulumi.getter(name="logStoreDay")
    def log_store_day(self) -> int:
        """
        The retention period of raw logs after you enable the log auditing feature.
        """
        return pulumi.get(self, "log_store_day")

    @property
    @pulumi.getter(name="parentId")
    def parent_id(self) -> str:
        """
        The ID of the data asset.
        """
        return pulumi.get(self, "parent_id")

    @property
    @pulumi.getter
    def port(self) -> int:
        """
        The port that is used to connect to the database.
        """
        return pulumi.get(self, "port")

    @property
    @pulumi.getter(name="resourceType")
    def resource_type(self) -> str:
        """
        The type of the service to which the data asset belongs.
        """
        return pulumi.get(self, "resource_type")

    @property
    @pulumi.getter(name="userName")
    def user_name(self) -> str:
        """
        The name of the user who owns the data asset.
        """
        return pulumi.get(self, "user_name")


@pulumi.output_type
class GetInstancesInstanceResult(dict):
    def __init__(__self__, *,
                 authed: bool,
                 id: str,
                 instance_id: str,
                 instance_num: str,
                 odps_set: bool,
                 oss_bucket_set: bool,
                 oss_size: str,
                 payment_type: str,
                 rds_set: bool,
                 status: str):
        """
        :param bool authed: Whether the required RAM authorization is configured.
        :param str instance_id: The ID of the instance.
        :param str instance_num: The number of instances.
        :param bool odps_set: Whether the authorized MaxCompute (ODPS) assets.
        :param bool oss_bucket_set: Whether the authorized oss assets.
        :param str oss_size: The OSS size of the instance.
        :param str payment_type: The payment type of the resource. Valid values: `Subscription`.
        :param bool rds_set: Whether the authorized rds assets.
        :param str status: The status of the resource.
        """
        pulumi.set(__self__, "authed", authed)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "instance_id", instance_id)
        pulumi.set(__self__, "instance_num", instance_num)
        pulumi.set(__self__, "odps_set", odps_set)
        pulumi.set(__self__, "oss_bucket_set", oss_bucket_set)
        pulumi.set(__self__, "oss_size", oss_size)
        pulumi.set(__self__, "payment_type", payment_type)
        pulumi.set(__self__, "rds_set", rds_set)
        pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter
    def authed(self) -> bool:
        """
        Whether the required RAM authorization is configured.
        """
        return pulumi.get(self, "authed")

    @property
    @pulumi.getter
    def id(self) -> str:
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> str:
        """
        The ID of the instance.
        """
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter(name="instanceNum")
    def instance_num(self) -> str:
        """
        The number of instances.
        """
        return pulumi.get(self, "instance_num")

    @property
    @pulumi.getter(name="odpsSet")
    def odps_set(self) -> bool:
        """
        Whether the authorized MaxCompute (ODPS) assets.
        """
        return pulumi.get(self, "odps_set")

    @property
    @pulumi.getter(name="ossBucketSet")
    def oss_bucket_set(self) -> bool:
        """
        Whether the authorized oss assets.
        """
        return pulumi.get(self, "oss_bucket_set")

    @property
    @pulumi.getter(name="ossSize")
    def oss_size(self) -> str:
        """
        The OSS size of the instance.
        """
        return pulumi.get(self, "oss_size")

    @property
    @pulumi.getter(name="paymentType")
    def payment_type(self) -> str:
        """
        The payment type of the resource. Valid values: `Subscription`.
        """
        return pulumi.get(self, "payment_type")

    @property
    @pulumi.getter(name="rdsSet")
    def rds_set(self) -> bool:
        """
        Whether the authorized rds assets.
        """
        return pulumi.get(self, "rds_set")

    @property
    @pulumi.getter
    def status(self) -> str:
        """
        The status of the resource.
        """
        return pulumi.get(self, "status")


@pulumi.output_type
class GetRulesRuleResult(dict):
    def __init__(__self__, *,
                 category: int,
                 category_name: str,
                 content: str,
                 content_category: str,
                 create_time: str,
                 custom_type: int,
                 description: str,
                 display_name: str,
                 gmt_modified: str,
                 id: str,
                 login_name: str,
                 major_key: str,
                 name: str,
                 product_code: str,
                 product_id: str,
                 risk_level_id: str,
                 risk_level_name: str,
                 rule_id: str,
                 stat_express: str,
                 status: int,
                 target: str,
                 user_id: str,
                 warn_level: int):
        """
        :param int category: Sensitive Data Identification Rules for the Type of.
        :param str category_name: Sensitive Data Identification Rules Belongs Type Name.
        :param str content: Sensitive Data Identification Rules the Content.
        :param str content_category: The Content Classification.
        :param str create_time: Sensitive Data Identification Rules the Creation Time of the Number of Milliseconds.
        :param int custom_type: Sensitive Data Identification Rules of Type. 0: the Built-in 1: The User-Defined.
        :param str description: Sensitive Data Identification a Description of the Rule Information.
        :param str display_name: Sensitive Data Identification Rules, Founder of Account Display Name.
        :param str gmt_modified: Sensitive Data Identification Rules to the Modified Time of the Number of Milliseconds.
        :param str id: The ID of the Rule.
        :param str login_name: Sensitive Data Identification Rules, Founder Of Account Login.
        :param str major_key: The Primary Key.
        :param str name: The name of rule.
        :param str product_code: Product Code.
        :param str product_id: Product ID.
        :param str risk_level_id: Sensitive Data Identification Rules of Risk Level ID. Valid values:1:S1, Weak Risk Level. 2:S2, Medium Risk Level. 3:S3 High Risk Level. 4:S4, the Highest Risk Level.
        :param str risk_level_name: Sensitive Data Identification Rules the Risk Level of. S1: Weak Risk Level S2: Moderate Risk Level S3: High Risk Level S4: the Highest Risk Level.
        :param str rule_id: The first ID of the resource.
        :param str stat_express: Triggered the Alarm Conditions.
        :param int status: Sensitive Data Identification Rules Detection State of.
        :param str target: The Target.
        :param str user_id: The User ID.
        :param int warn_level: The Level of Risk.
        """
        pulumi.set(__self__, "category", category)
        pulumi.set(__self__, "category_name", category_name)
        pulumi.set(__self__, "content", content)
        pulumi.set(__self__, "content_category", content_category)
        pulumi.set(__self__, "create_time", create_time)
        pulumi.set(__self__, "custom_type", custom_type)
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "display_name", display_name)
        pulumi.set(__self__, "gmt_modified", gmt_modified)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "login_name", login_name)
        pulumi.set(__self__, "major_key", major_key)
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "product_code", product_code)
        pulumi.set(__self__, "product_id", product_id)
        pulumi.set(__self__, "risk_level_id", risk_level_id)
        pulumi.set(__self__, "risk_level_name", risk_level_name)
        pulumi.set(__self__, "rule_id", rule_id)
        pulumi.set(__self__, "stat_express", stat_express)
        pulumi.set(__self__, "status", status)
        pulumi.set(__self__, "target", target)
        pulumi.set(__self__, "user_id", user_id)
        pulumi.set(__self__, "warn_level", warn_level)

    @property
    @pulumi.getter
    def category(self) -> int:
        """
        Sensitive Data Identification Rules for the Type of.
        """
        return pulumi.get(self, "category")

    @property
    @pulumi.getter(name="categoryName")
    def category_name(self) -> str:
        """
        Sensitive Data Identification Rules Belongs Type Name.
        """
        return pulumi.get(self, "category_name")

    @property
    @pulumi.getter
    def content(self) -> str:
        """
        Sensitive Data Identification Rules the Content.
        """
        return pulumi.get(self, "content")

    @property
    @pulumi.getter(name="contentCategory")
    def content_category(self) -> str:
        """
        The Content Classification.
        """
        return pulumi.get(self, "content_category")

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> str:
        """
        Sensitive Data Identification Rules the Creation Time of the Number of Milliseconds.
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter(name="customType")
    def custom_type(self) -> int:
        """
        Sensitive Data Identification Rules of Type. 0: the Built-in 1: The User-Defined.
        """
        return pulumi.get(self, "custom_type")

    @property
    @pulumi.getter
    def description(self) -> str:
        """
        Sensitive Data Identification a Description of the Rule Information.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> str:
        """
        Sensitive Data Identification Rules, Founder of Account Display Name.
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter(name="gmtModified")
    def gmt_modified(self) -> str:
        """
        Sensitive Data Identification Rules to the Modified Time of the Number of Milliseconds.
        """
        return pulumi.get(self, "gmt_modified")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The ID of the Rule.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="loginName")
    def login_name(self) -> str:
        """
        Sensitive Data Identification Rules, Founder Of Account Login.
        """
        return pulumi.get(self, "login_name")

    @property
    @pulumi.getter(name="majorKey")
    def major_key(self) -> str:
        """
        The Primary Key.
        """
        return pulumi.get(self, "major_key")

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        The name of rule.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="productCode")
    def product_code(self) -> str:
        """
        Product Code.
        """
        return pulumi.get(self, "product_code")

    @property
    @pulumi.getter(name="productId")
    def product_id(self) -> str:
        """
        Product ID.
        """
        return pulumi.get(self, "product_id")

    @property
    @pulumi.getter(name="riskLevelId")
    def risk_level_id(self) -> str:
        """
        Sensitive Data Identification Rules of Risk Level ID. Valid values:1:S1, Weak Risk Level. 2:S2, Medium Risk Level. 3:S3 High Risk Level. 4:S4, the Highest Risk Level.
        """
        return pulumi.get(self, "risk_level_id")

    @property
    @pulumi.getter(name="riskLevelName")
    def risk_level_name(self) -> str:
        """
        Sensitive Data Identification Rules the Risk Level of. S1: Weak Risk Level S2: Moderate Risk Level S3: High Risk Level S4: the Highest Risk Level.
        """
        return pulumi.get(self, "risk_level_name")

    @property
    @pulumi.getter(name="ruleId")
    def rule_id(self) -> str:
        """
        The first ID of the resource.
        """
        return pulumi.get(self, "rule_id")

    @property
    @pulumi.getter(name="statExpress")
    def stat_express(self) -> str:
        """
        Triggered the Alarm Conditions.
        """
        return pulumi.get(self, "stat_express")

    @property
    @pulumi.getter
    def status(self) -> int:
        """
        Sensitive Data Identification Rules Detection State of.
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def target(self) -> str:
        """
        The Target.
        """
        return pulumi.get(self, "target")

    @property
    @pulumi.getter(name="userId")
    def user_id(self) -> str:
        """
        The User ID.
        """
        return pulumi.get(self, "user_id")

    @property
    @pulumi.getter(name="warnLevel")
    def warn_level(self) -> int:
        """
        The Level of Risk.
        """
        return pulumi.get(self, "warn_level")





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['InstanceArgs', 'Instance']

@pulumi.input_type
class InstanceArgs:
    def __init__(__self__, *,
                 payment_type: pulumi.Input[str],
                 auto_renew: Optional[pulumi.Input[bool]] = None,
                 instance_name: Optional[pulumi.Input[str]] = None,
                 instance_type: Optional[pulumi.Input[str]] = None,
                 max_connections: Optional[pulumi.Input[int]] = None,
                 max_eip_tps: Optional[pulumi.Input[str]] = None,
                 max_tps: Optional[pulumi.Input[str]] = None,
                 modify_type: Optional[pulumi.Input[str]] = None,
                 period: Optional[pulumi.Input[int]] = None,
                 period_cycle: Optional[pulumi.Input[str]] = None,
                 queue_capacity: Optional[pulumi.Input[str]] = None,
                 renewal_duration: Optional[pulumi.Input[int]] = None,
                 renewal_duration_unit: Optional[pulumi.Input[str]] = None,
                 renewal_status: Optional[pulumi.Input[str]] = None,
                 serverless_charge_type: Optional[pulumi.Input[str]] = None,
                 storage_size: Optional[pulumi.Input[str]] = None,
                 support_eip: Optional[pulumi.Input[bool]] = None,
                 support_tracing: Optional[pulumi.Input[bool]] = None,
                 tracing_storage_time: Optional[pulumi.Input[int]] = None):
        """
        The set of arguments for constructing a Instance resource.
        :param pulumi.Input[str] payment_type: The Payment type. Valid value: Subscription: prepaid. PayAsYouGo: Post-paid.
        :param pulumi.Input[bool] auto_renew: Renewal method. Automatic renewal: true; Manual renewal: false. When RenewalStatus has a value, the value of RenewalStatus shall prevail.
        :param pulumi.Input[str] instance_name: The instance name.
        :param pulumi.Input[str] instance_type: Instance type. Valid values are as follows:  professional: professional Edition enterprise: enterprise Edition vip: Platinum Edition.
        :param pulumi.Input[int] max_connections: The maximum number of connections, according to the value given on the purchase page of the cloud message queue RabbitMQ version console.
        :param pulumi.Input[str] max_eip_tps: Peak TPS traffic of the public network, which must be a multiple of 128, unit: times per second.
        :param pulumi.Input[str] max_tps: Configure the private network TPS traffic peak, please set the value according to the cloud message queue RabbitMQ version of the console purchase page given.
        :param pulumi.Input[str] modify_type: This parameter must be provided while you change the instance specification. Type of instance lifting and lowering:
               - Upgrade: Upgrade
               - Downgrade: Downgrading.
        :param pulumi.Input[int] period: Prepayment cycle, unit: periodCycle.  This parameter is valid when PaymentType is set to Subscription.
        :param pulumi.Input[str] period_cycle: Prepaid cycle units. Value: Month. Year: Year.
        :param pulumi.Input[str] queue_capacity: Configure the maximum number of queues. The value range is as follows:  Professional version:[50,1000], minimum modification step size is 5  Enterprise Edition:[200,6000], minimum modification step size is 100  Platinum version:[10000,80000], minimum modification step size is 100.
        :param pulumi.Input[int] renewal_duration: The number of automatic renewal cycles.
        :param pulumi.Input[str] renewal_duration_unit: Auto-Renewal Cycle Unit Values Include: Month: Month. Year: Years.
        :param pulumi.Input[str] renewal_status: The renewal status. Value: AutoRenewal: automatic renewal. ManualRenewal: manual renewal. NotRenewal: no renewal.
        :param pulumi.Input[str] serverless_charge_type: The billing type of the serverless instance. Value: onDemand.
        :param pulumi.Input[str] storage_size: Configure the message storage space. Unit: GB. The value is as follows:  Professional Edition and Enterprise Edition: Fixed to 0. Description A value of 0 indicates that the Professional Edition and Enterprise Edition instances do not charge storage fees, but do not have storage space. Platinum version example: m × 100, where the value range of m is [7,28].
        :param pulumi.Input[bool] support_eip: Whether to support public network.
        :param pulumi.Input[bool] support_tracing: Whether to activate the message trace function. The values are as follows:  true: Enable message trace function false: message trace function is not enabled Description The Platinum Edition instance provides the 15-day message trace function free of charge. The trace function can only be enabled and the trace storage duration can only be set to 15 days. For instances of other specifications, you can enable or disable the trace function.
        :param pulumi.Input[int] tracing_storage_time: Configure the storage duration of message traces. Unit: Days. The value is as follows:  3:3 days 7:7 days 15:15 days This parameter is valid when SupportTracing is true.
        """
        pulumi.set(__self__, "payment_type", payment_type)
        if auto_renew is not None:
            pulumi.set(__self__, "auto_renew", auto_renew)
        if instance_name is not None:
            pulumi.set(__self__, "instance_name", instance_name)
        if instance_type is not None:
            pulumi.set(__self__, "instance_type", instance_type)
        if max_connections is not None:
            pulumi.set(__self__, "max_connections", max_connections)
        if max_eip_tps is not None:
            pulumi.set(__self__, "max_eip_tps", max_eip_tps)
        if max_tps is not None:
            pulumi.set(__self__, "max_tps", max_tps)
        if modify_type is not None:
            pulumi.set(__self__, "modify_type", modify_type)
        if period is not None:
            pulumi.set(__self__, "period", period)
        if period_cycle is not None:
            pulumi.set(__self__, "period_cycle", period_cycle)
        if queue_capacity is not None:
            pulumi.set(__self__, "queue_capacity", queue_capacity)
        if renewal_duration is not None:
            pulumi.set(__self__, "renewal_duration", renewal_duration)
        if renewal_duration_unit is not None:
            pulumi.set(__self__, "renewal_duration_unit", renewal_duration_unit)
        if renewal_status is not None:
            pulumi.set(__self__, "renewal_status", renewal_status)
        if serverless_charge_type is not None:
            pulumi.set(__self__, "serverless_charge_type", serverless_charge_type)
        if storage_size is not None:
            pulumi.set(__self__, "storage_size", storage_size)
        if support_eip is not None:
            pulumi.set(__self__, "support_eip", support_eip)
        if support_tracing is not None:
            pulumi.set(__self__, "support_tracing", support_tracing)
        if tracing_storage_time is not None:
            pulumi.set(__self__, "tracing_storage_time", tracing_storage_time)

    @property
    @pulumi.getter(name="paymentType")
    def payment_type(self) -> pulumi.Input[str]:
        """
        The Payment type. Valid value: Subscription: prepaid. PayAsYouGo: Post-paid.
        """
        return pulumi.get(self, "payment_type")

    @payment_type.setter
    def payment_type(self, value: pulumi.Input[str]):
        pulumi.set(self, "payment_type", value)

    @property
    @pulumi.getter(name="autoRenew")
    def auto_renew(self) -> Optional[pulumi.Input[bool]]:
        """
        Renewal method. Automatic renewal: true; Manual renewal: false. When RenewalStatus has a value, the value of RenewalStatus shall prevail.
        """
        return pulumi.get(self, "auto_renew")

    @auto_renew.setter
    def auto_renew(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "auto_renew", value)

    @property
    @pulumi.getter(name="instanceName")
    def instance_name(self) -> Optional[pulumi.Input[str]]:
        """
        The instance name.
        """
        return pulumi.get(self, "instance_name")

    @instance_name.setter
    def instance_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "instance_name", value)

    @property
    @pulumi.getter(name="instanceType")
    def instance_type(self) -> Optional[pulumi.Input[str]]:
        """
        Instance type. Valid values are as follows:  professional: professional Edition enterprise: enterprise Edition vip: Platinum Edition.
        """
        return pulumi.get(self, "instance_type")

    @instance_type.setter
    def instance_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "instance_type", value)

    @property
    @pulumi.getter(name="maxConnections")
    def max_connections(self) -> Optional[pulumi.Input[int]]:
        """
        The maximum number of connections, according to the value given on the purchase page of the cloud message queue RabbitMQ version console.
        """
        return pulumi.get(self, "max_connections")

    @max_connections.setter
    def max_connections(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "max_connections", value)

    @property
    @pulumi.getter(name="maxEipTps")
    def max_eip_tps(self) -> Optional[pulumi.Input[str]]:
        """
        Peak TPS traffic of the public network, which must be a multiple of 128, unit: times per second.
        """
        return pulumi.get(self, "max_eip_tps")

    @max_eip_tps.setter
    def max_eip_tps(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "max_eip_tps", value)

    @property
    @pulumi.getter(name="maxTps")
    def max_tps(self) -> Optional[pulumi.Input[str]]:
        """
        Configure the private network TPS traffic peak, please set the value according to the cloud message queue RabbitMQ version of the console purchase page given.
        """
        return pulumi.get(self, "max_tps")

    @max_tps.setter
    def max_tps(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "max_tps", value)

    @property
    @pulumi.getter(name="modifyType")
    def modify_type(self) -> Optional[pulumi.Input[str]]:
        """
        This parameter must be provided while you change the instance specification. Type of instance lifting and lowering:
        - Upgrade: Upgrade
        - Downgrade: Downgrading.
        """
        return pulumi.get(self, "modify_type")

    @modify_type.setter
    def modify_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "modify_type", value)

    @property
    @pulumi.getter
    def period(self) -> Optional[pulumi.Input[int]]:
        """
        Prepayment cycle, unit: periodCycle.  This parameter is valid when PaymentType is set to Subscription.
        """
        return pulumi.get(self, "period")

    @period.setter
    def period(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "period", value)

    @property
    @pulumi.getter(name="periodCycle")
    def period_cycle(self) -> Optional[pulumi.Input[str]]:
        """
        Prepaid cycle units. Value: Month. Year: Year.
        """
        return pulumi.get(self, "period_cycle")

    @period_cycle.setter
    def period_cycle(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "period_cycle", value)

    @property
    @pulumi.getter(name="queueCapacity")
    def queue_capacity(self) -> Optional[pulumi.Input[str]]:
        """
        Configure the maximum number of queues. The value range is as follows:  Professional version:[50,1000], minimum modification step size is 5  Enterprise Edition:[200,6000], minimum modification step size is 100  Platinum version:[10000,80000], minimum modification step size is 100.
        """
        return pulumi.get(self, "queue_capacity")

    @queue_capacity.setter
    def queue_capacity(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "queue_capacity", value)

    @property
    @pulumi.getter(name="renewalDuration")
    def renewal_duration(self) -> Optional[pulumi.Input[int]]:
        """
        The number of automatic renewal cycles.
        """
        return pulumi.get(self, "renewal_duration")

    @renewal_duration.setter
    def renewal_duration(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "renewal_duration", value)

    @property
    @pulumi.getter(name="renewalDurationUnit")
    def renewal_duration_unit(self) -> Optional[pulumi.Input[str]]:
        """
        Auto-Renewal Cycle Unit Values Include: Month: Month. Year: Years.
        """
        return pulumi.get(self, "renewal_duration_unit")

    @renewal_duration_unit.setter
    def renewal_duration_unit(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "renewal_duration_unit", value)

    @property
    @pulumi.getter(name="renewalStatus")
    def renewal_status(self) -> Optional[pulumi.Input[str]]:
        """
        The renewal status. Value: AutoRenewal: automatic renewal. ManualRenewal: manual renewal. NotRenewal: no renewal.
        """
        return pulumi.get(self, "renewal_status")

    @renewal_status.setter
    def renewal_status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "renewal_status", value)

    @property
    @pulumi.getter(name="serverlessChargeType")
    def serverless_charge_type(self) -> Optional[pulumi.Input[str]]:
        """
        The billing type of the serverless instance. Value: onDemand.
        """
        return pulumi.get(self, "serverless_charge_type")

    @serverless_charge_type.setter
    def serverless_charge_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "serverless_charge_type", value)

    @property
    @pulumi.getter(name="storageSize")
    def storage_size(self) -> Optional[pulumi.Input[str]]:
        """
        Configure the message storage space. Unit: GB. The value is as follows:  Professional Edition and Enterprise Edition: Fixed to 0. Description A value of 0 indicates that the Professional Edition and Enterprise Edition instances do not charge storage fees, but do not have storage space. Platinum version example: m × 100, where the value range of m is [7,28].
        """
        return pulumi.get(self, "storage_size")

    @storage_size.setter
    def storage_size(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "storage_size", value)

    @property
    @pulumi.getter(name="supportEip")
    def support_eip(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether to support public network.
        """
        return pulumi.get(self, "support_eip")

    @support_eip.setter
    def support_eip(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "support_eip", value)

    @property
    @pulumi.getter(name="supportTracing")
    def support_tracing(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether to activate the message trace function. The values are as follows:  true: Enable message trace function false: message trace function is not enabled Description The Platinum Edition instance provides the 15-day message trace function free of charge. The trace function can only be enabled and the trace storage duration can only be set to 15 days. For instances of other specifications, you can enable or disable the trace function.
        """
        return pulumi.get(self, "support_tracing")

    @support_tracing.setter
    def support_tracing(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "support_tracing", value)

    @property
    @pulumi.getter(name="tracingStorageTime")
    def tracing_storage_time(self) -> Optional[pulumi.Input[int]]:
        """
        Configure the storage duration of message traces. Unit: Days. The value is as follows:  3:3 days 7:7 days 15:15 days This parameter is valid when SupportTracing is true.
        """
        return pulumi.get(self, "tracing_storage_time")

    @tracing_storage_time.setter
    def tracing_storage_time(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "tracing_storage_time", value)


@pulumi.input_type
class _InstanceState:
    def __init__(__self__, *,
                 auto_renew: Optional[pulumi.Input[bool]] = None,
                 create_time: Optional[pulumi.Input[int]] = None,
                 instance_name: Optional[pulumi.Input[str]] = None,
                 instance_type: Optional[pulumi.Input[str]] = None,
                 max_connections: Optional[pulumi.Input[int]] = None,
                 max_eip_tps: Optional[pulumi.Input[str]] = None,
                 max_tps: Optional[pulumi.Input[str]] = None,
                 modify_type: Optional[pulumi.Input[str]] = None,
                 payment_type: Optional[pulumi.Input[str]] = None,
                 period: Optional[pulumi.Input[int]] = None,
                 period_cycle: Optional[pulumi.Input[str]] = None,
                 queue_capacity: Optional[pulumi.Input[str]] = None,
                 renewal_duration: Optional[pulumi.Input[int]] = None,
                 renewal_duration_unit: Optional[pulumi.Input[str]] = None,
                 renewal_status: Optional[pulumi.Input[str]] = None,
                 serverless_charge_type: Optional[pulumi.Input[str]] = None,
                 status: Optional[pulumi.Input[str]] = None,
                 storage_size: Optional[pulumi.Input[str]] = None,
                 support_eip: Optional[pulumi.Input[bool]] = None,
                 support_tracing: Optional[pulumi.Input[bool]] = None,
                 tracing_storage_time: Optional[pulumi.Input[int]] = None):
        """
        Input properties used for looking up and filtering Instance resources.
        :param pulumi.Input[bool] auto_renew: Renewal method. Automatic renewal: true; Manual renewal: false. When RenewalStatus has a value, the value of RenewalStatus shall prevail.
        :param pulumi.Input[int] create_time: OrderCreateTime.
        :param pulumi.Input[str] instance_name: The instance name.
        :param pulumi.Input[str] instance_type: Instance type. Valid values are as follows:  professional: professional Edition enterprise: enterprise Edition vip: Platinum Edition.
        :param pulumi.Input[int] max_connections: The maximum number of connections, according to the value given on the purchase page of the cloud message queue RabbitMQ version console.
        :param pulumi.Input[str] max_eip_tps: Peak TPS traffic of the public network, which must be a multiple of 128, unit: times per second.
        :param pulumi.Input[str] max_tps: Configure the private network TPS traffic peak, please set the value according to the cloud message queue RabbitMQ version of the console purchase page given.
        :param pulumi.Input[str] modify_type: This parameter must be provided while you change the instance specification. Type of instance lifting and lowering:
               - Upgrade: Upgrade
               - Downgrade: Downgrading.
        :param pulumi.Input[str] payment_type: The Payment type. Valid value: Subscription: prepaid. PayAsYouGo: Post-paid.
        :param pulumi.Input[int] period: Prepayment cycle, unit: periodCycle.  This parameter is valid when PaymentType is set to Subscription.
        :param pulumi.Input[str] period_cycle: Prepaid cycle units. Value: Month. Year: Year.
        :param pulumi.Input[str] queue_capacity: Configure the maximum number of queues. The value range is as follows:  Professional version:[50,1000], minimum modification step size is 5  Enterprise Edition:[200,6000], minimum modification step size is 100  Platinum version:[10000,80000], minimum modification step size is 100.
        :param pulumi.Input[int] renewal_duration: The number of automatic renewal cycles.
        :param pulumi.Input[str] renewal_duration_unit: Auto-Renewal Cycle Unit Values Include: Month: Month. Year: Years.
        :param pulumi.Input[str] renewal_status: The renewal status. Value: AutoRenewal: automatic renewal. ManualRenewal: manual renewal. NotRenewal: no renewal.
        :param pulumi.Input[str] serverless_charge_type: The billing type of the serverless instance. Value: onDemand.
        :param pulumi.Input[str] status: The status of the resource.
        :param pulumi.Input[str] storage_size: Configure the message storage space. Unit: GB. The value is as follows:  Professional Edition and Enterprise Edition: Fixed to 0. Description A value of 0 indicates that the Professional Edition and Enterprise Edition instances do not charge storage fees, but do not have storage space. Platinum version example: m × 100, where the value range of m is [7,28].
        :param pulumi.Input[bool] support_eip: Whether to support public network.
        :param pulumi.Input[bool] support_tracing: Whether to activate the message trace function. The values are as follows:  true: Enable message trace function false: message trace function is not enabled Description The Platinum Edition instance provides the 15-day message trace function free of charge. The trace function can only be enabled and the trace storage duration can only be set to 15 days. For instances of other specifications, you can enable or disable the trace function.
        :param pulumi.Input[int] tracing_storage_time: Configure the storage duration of message traces. Unit: Days. The value is as follows:  3:3 days 7:7 days 15:15 days This parameter is valid when SupportTracing is true.
        """
        if auto_renew is not None:
            pulumi.set(__self__, "auto_renew", auto_renew)
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if instance_name is not None:
            pulumi.set(__self__, "instance_name", instance_name)
        if instance_type is not None:
            pulumi.set(__self__, "instance_type", instance_type)
        if max_connections is not None:
            pulumi.set(__self__, "max_connections", max_connections)
        if max_eip_tps is not None:
            pulumi.set(__self__, "max_eip_tps", max_eip_tps)
        if max_tps is not None:
            pulumi.set(__self__, "max_tps", max_tps)
        if modify_type is not None:
            pulumi.set(__self__, "modify_type", modify_type)
        if payment_type is not None:
            pulumi.set(__self__, "payment_type", payment_type)
        if period is not None:
            pulumi.set(__self__, "period", period)
        if period_cycle is not None:
            pulumi.set(__self__, "period_cycle", period_cycle)
        if queue_capacity is not None:
            pulumi.set(__self__, "queue_capacity", queue_capacity)
        if renewal_duration is not None:
            pulumi.set(__self__, "renewal_duration", renewal_duration)
        if renewal_duration_unit is not None:
            pulumi.set(__self__, "renewal_duration_unit", renewal_duration_unit)
        if renewal_status is not None:
            pulumi.set(__self__, "renewal_status", renewal_status)
        if serverless_charge_type is not None:
            pulumi.set(__self__, "serverless_charge_type", serverless_charge_type)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if storage_size is not None:
            pulumi.set(__self__, "storage_size", storage_size)
        if support_eip is not None:
            pulumi.set(__self__, "support_eip", support_eip)
        if support_tracing is not None:
            pulumi.set(__self__, "support_tracing", support_tracing)
        if tracing_storage_time is not None:
            pulumi.set(__self__, "tracing_storage_time", tracing_storage_time)

    @property
    @pulumi.getter(name="autoRenew")
    def auto_renew(self) -> Optional[pulumi.Input[bool]]:
        """
        Renewal method. Automatic renewal: true; Manual renewal: false. When RenewalStatus has a value, the value of RenewalStatus shall prevail.
        """
        return pulumi.get(self, "auto_renew")

    @auto_renew.setter
    def auto_renew(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "auto_renew", value)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[pulumi.Input[int]]:
        """
        OrderCreateTime.
        """
        return pulumi.get(self, "create_time")

    @create_time.setter
    def create_time(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "create_time", value)

    @property
    @pulumi.getter(name="instanceName")
    def instance_name(self) -> Optional[pulumi.Input[str]]:
        """
        The instance name.
        """
        return pulumi.get(self, "instance_name")

    @instance_name.setter
    def instance_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "instance_name", value)

    @property
    @pulumi.getter(name="instanceType")
    def instance_type(self) -> Optional[pulumi.Input[str]]:
        """
        Instance type. Valid values are as follows:  professional: professional Edition enterprise: enterprise Edition vip: Platinum Edition.
        """
        return pulumi.get(self, "instance_type")

    @instance_type.setter
    def instance_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "instance_type", value)

    @property
    @pulumi.getter(name="maxConnections")
    def max_connections(self) -> Optional[pulumi.Input[int]]:
        """
        The maximum number of connections, according to the value given on the purchase page of the cloud message queue RabbitMQ version console.
        """
        return pulumi.get(self, "max_connections")

    @max_connections.setter
    def max_connections(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "max_connections", value)

    @property
    @pulumi.getter(name="maxEipTps")
    def max_eip_tps(self) -> Optional[pulumi.Input[str]]:
        """
        Peak TPS traffic of the public network, which must be a multiple of 128, unit: times per second.
        """
        return pulumi.get(self, "max_eip_tps")

    @max_eip_tps.setter
    def max_eip_tps(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "max_eip_tps", value)

    @property
    @pulumi.getter(name="maxTps")
    def max_tps(self) -> Optional[pulumi.Input[str]]:
        """
        Configure the private network TPS traffic peak, please set the value according to the cloud message queue RabbitMQ version of the console purchase page given.
        """
        return pulumi.get(self, "max_tps")

    @max_tps.setter
    def max_tps(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "max_tps", value)

    @property
    @pulumi.getter(name="modifyType")
    def modify_type(self) -> Optional[pulumi.Input[str]]:
        """
        This parameter must be provided while you change the instance specification. Type of instance lifting and lowering:
        - Upgrade: Upgrade
        - Downgrade: Downgrading.
        """
        return pulumi.get(self, "modify_type")

    @modify_type.setter
    def modify_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "modify_type", value)

    @property
    @pulumi.getter(name="paymentType")
    def payment_type(self) -> Optional[pulumi.Input[str]]:
        """
        The Payment type. Valid value: Subscription: prepaid. PayAsYouGo: Post-paid.
        """
        return pulumi.get(self, "payment_type")

    @payment_type.setter
    def payment_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "payment_type", value)

    @property
    @pulumi.getter
    def period(self) -> Optional[pulumi.Input[int]]:
        """
        Prepayment cycle, unit: periodCycle.  This parameter is valid when PaymentType is set to Subscription.
        """
        return pulumi.get(self, "period")

    @period.setter
    def period(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "period", value)

    @property
    @pulumi.getter(name="periodCycle")
    def period_cycle(self) -> Optional[pulumi.Input[str]]:
        """
        Prepaid cycle units. Value: Month. Year: Year.
        """
        return pulumi.get(self, "period_cycle")

    @period_cycle.setter
    def period_cycle(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "period_cycle", value)

    @property
    @pulumi.getter(name="queueCapacity")
    def queue_capacity(self) -> Optional[pulumi.Input[str]]:
        """
        Configure the maximum number of queues. The value range is as follows:  Professional version:[50,1000], minimum modification step size is 5  Enterprise Edition:[200,6000], minimum modification step size is 100  Platinum version:[10000,80000], minimum modification step size is 100.
        """
        return pulumi.get(self, "queue_capacity")

    @queue_capacity.setter
    def queue_capacity(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "queue_capacity", value)

    @property
    @pulumi.getter(name="renewalDuration")
    def renewal_duration(self) -> Optional[pulumi.Input[int]]:
        """
        The number of automatic renewal cycles.
        """
        return pulumi.get(self, "renewal_duration")

    @renewal_duration.setter
    def renewal_duration(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "renewal_duration", value)

    @property
    @pulumi.getter(name="renewalDurationUnit")
    def renewal_duration_unit(self) -> Optional[pulumi.Input[str]]:
        """
        Auto-Renewal Cycle Unit Values Include: Month: Month. Year: Years.
        """
        return pulumi.get(self, "renewal_duration_unit")

    @renewal_duration_unit.setter
    def renewal_duration_unit(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "renewal_duration_unit", value)

    @property
    @pulumi.getter(name="renewalStatus")
    def renewal_status(self) -> Optional[pulumi.Input[str]]:
        """
        The renewal status. Value: AutoRenewal: automatic renewal. ManualRenewal: manual renewal. NotRenewal: no renewal.
        """
        return pulumi.get(self, "renewal_status")

    @renewal_status.setter
    def renewal_status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "renewal_status", value)

    @property
    @pulumi.getter(name="serverlessChargeType")
    def serverless_charge_type(self) -> Optional[pulumi.Input[str]]:
        """
        The billing type of the serverless instance. Value: onDemand.
        """
        return pulumi.get(self, "serverless_charge_type")

    @serverless_charge_type.setter
    def serverless_charge_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "serverless_charge_type", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[str]]:
        """
        The status of the resource.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter(name="storageSize")
    def storage_size(self) -> Optional[pulumi.Input[str]]:
        """
        Configure the message storage space. Unit: GB. The value is as follows:  Professional Edition and Enterprise Edition: Fixed to 0. Description A value of 0 indicates that the Professional Edition and Enterprise Edition instances do not charge storage fees, but do not have storage space. Platinum version example: m × 100, where the value range of m is [7,28].
        """
        return pulumi.get(self, "storage_size")

    @storage_size.setter
    def storage_size(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "storage_size", value)

    @property
    @pulumi.getter(name="supportEip")
    def support_eip(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether to support public network.
        """
        return pulumi.get(self, "support_eip")

    @support_eip.setter
    def support_eip(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "support_eip", value)

    @property
    @pulumi.getter(name="supportTracing")
    def support_tracing(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether to activate the message trace function. The values are as follows:  true: Enable message trace function false: message trace function is not enabled Description The Platinum Edition instance provides the 15-day message trace function free of charge. The trace function can only be enabled and the trace storage duration can only be set to 15 days. For instances of other specifications, you can enable or disable the trace function.
        """
        return pulumi.get(self, "support_tracing")

    @support_tracing.setter
    def support_tracing(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "support_tracing", value)

    @property
    @pulumi.getter(name="tracingStorageTime")
    def tracing_storage_time(self) -> Optional[pulumi.Input[int]]:
        """
        Configure the storage duration of message traces. Unit: Days. The value is as follows:  3:3 days 7:7 days 15:15 days This parameter is valid when SupportTracing is true.
        """
        return pulumi.get(self, "tracing_storage_time")

    @tracing_storage_time.setter
    def tracing_storage_time(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "tracing_storage_time", value)


class Instance(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 auto_renew: Optional[pulumi.Input[bool]] = None,
                 instance_name: Optional[pulumi.Input[str]] = None,
                 instance_type: Optional[pulumi.Input[str]] = None,
                 max_connections: Optional[pulumi.Input[int]] = None,
                 max_eip_tps: Optional[pulumi.Input[str]] = None,
                 max_tps: Optional[pulumi.Input[str]] = None,
                 modify_type: Optional[pulumi.Input[str]] = None,
                 payment_type: Optional[pulumi.Input[str]] = None,
                 period: Optional[pulumi.Input[int]] = None,
                 period_cycle: Optional[pulumi.Input[str]] = None,
                 queue_capacity: Optional[pulumi.Input[str]] = None,
                 renewal_duration: Optional[pulumi.Input[int]] = None,
                 renewal_duration_unit: Optional[pulumi.Input[str]] = None,
                 renewal_status: Optional[pulumi.Input[str]] = None,
                 serverless_charge_type: Optional[pulumi.Input[str]] = None,
                 storage_size: Optional[pulumi.Input[str]] = None,
                 support_eip: Optional[pulumi.Input[bool]] = None,
                 support_tracing: Optional[pulumi.Input[bool]] = None,
                 tracing_storage_time: Optional[pulumi.Input[int]] = None,
                 __props__=None):
        """
        ## Import

        Amqp Instance can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:amqp/instance:Instance example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] auto_renew: Renewal method. Automatic renewal: true; Manual renewal: false. When RenewalStatus has a value, the value of RenewalStatus shall prevail.
        :param pulumi.Input[str] instance_name: The instance name.
        :param pulumi.Input[str] instance_type: Instance type. Valid values are as follows:  professional: professional Edition enterprise: enterprise Edition vip: Platinum Edition.
        :param pulumi.Input[int] max_connections: The maximum number of connections, according to the value given on the purchase page of the cloud message queue RabbitMQ version console.
        :param pulumi.Input[str] max_eip_tps: Peak TPS traffic of the public network, which must be a multiple of 128, unit: times per second.
        :param pulumi.Input[str] max_tps: Configure the private network TPS traffic peak, please set the value according to the cloud message queue RabbitMQ version of the console purchase page given.
        :param pulumi.Input[str] modify_type: This parameter must be provided while you change the instance specification. Type of instance lifting and lowering:
               - Upgrade: Upgrade
               - Downgrade: Downgrading.
        :param pulumi.Input[str] payment_type: The Payment type. Valid value: Subscription: prepaid. PayAsYouGo: Post-paid.
        :param pulumi.Input[int] period: Prepayment cycle, unit: periodCycle.  This parameter is valid when PaymentType is set to Subscription.
        :param pulumi.Input[str] period_cycle: Prepaid cycle units. Value: Month. Year: Year.
        :param pulumi.Input[str] queue_capacity: Configure the maximum number of queues. The value range is as follows:  Professional version:[50,1000], minimum modification step size is 5  Enterprise Edition:[200,6000], minimum modification step size is 100  Platinum version:[10000,80000], minimum modification step size is 100.
        :param pulumi.Input[int] renewal_duration: The number of automatic renewal cycles.
        :param pulumi.Input[str] renewal_duration_unit: Auto-Renewal Cycle Unit Values Include: Month: Month. Year: Years.
        :param pulumi.Input[str] renewal_status: The renewal status. Value: AutoRenewal: automatic renewal. ManualRenewal: manual renewal. NotRenewal: no renewal.
        :param pulumi.Input[str] serverless_charge_type: The billing type of the serverless instance. Value: onDemand.
        :param pulumi.Input[str] storage_size: Configure the message storage space. Unit: GB. The value is as follows:  Professional Edition and Enterprise Edition: Fixed to 0. Description A value of 0 indicates that the Professional Edition and Enterprise Edition instances do not charge storage fees, but do not have storage space. Platinum version example: m × 100, where the value range of m is [7,28].
        :param pulumi.Input[bool] support_eip: Whether to support public network.
        :param pulumi.Input[bool] support_tracing: Whether to activate the message trace function. The values are as follows:  true: Enable message trace function false: message trace function is not enabled Description The Platinum Edition instance provides the 15-day message trace function free of charge. The trace function can only be enabled and the trace storage duration can only be set to 15 days. For instances of other specifications, you can enable or disable the trace function.
        :param pulumi.Input[int] tracing_storage_time: Configure the storage duration of message traces. Unit: Days. The value is as follows:  3:3 days 7:7 days 15:15 days This parameter is valid when SupportTracing is true.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: InstanceArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Import

        Amqp Instance can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:amqp/instance:Instance example <id>
        ```

        :param str resource_name: The name of the resource.
        :param InstanceArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(InstanceArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 auto_renew: Optional[pulumi.Input[bool]] = None,
                 instance_name: Optional[pulumi.Input[str]] = None,
                 instance_type: Optional[pulumi.Input[str]] = None,
                 max_connections: Optional[pulumi.Input[int]] = None,
                 max_eip_tps: Optional[pulumi.Input[str]] = None,
                 max_tps: Optional[pulumi.Input[str]] = None,
                 modify_type: Optional[pulumi.Input[str]] = None,
                 payment_type: Optional[pulumi.Input[str]] = None,
                 period: Optional[pulumi.Input[int]] = None,
                 period_cycle: Optional[pulumi.Input[str]] = None,
                 queue_capacity: Optional[pulumi.Input[str]] = None,
                 renewal_duration: Optional[pulumi.Input[int]] = None,
                 renewal_duration_unit: Optional[pulumi.Input[str]] = None,
                 renewal_status: Optional[pulumi.Input[str]] = None,
                 serverless_charge_type: Optional[pulumi.Input[str]] = None,
                 storage_size: Optional[pulumi.Input[str]] = None,
                 support_eip: Optional[pulumi.Input[bool]] = None,
                 support_tracing: Optional[pulumi.Input[bool]] = None,
                 tracing_storage_time: Optional[pulumi.Input[int]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = InstanceArgs.__new__(InstanceArgs)

            __props__.__dict__["auto_renew"] = auto_renew
            __props__.__dict__["instance_name"] = instance_name
            __props__.__dict__["instance_type"] = instance_type
            __props__.__dict__["max_connections"] = max_connections
            __props__.__dict__["max_eip_tps"] = max_eip_tps
            __props__.__dict__["max_tps"] = max_tps
            __props__.__dict__["modify_type"] = modify_type
            if payment_type is None and not opts.urn:
                raise TypeError("Missing required property 'payment_type'")
            __props__.__dict__["payment_type"] = payment_type
            __props__.__dict__["period"] = period
            __props__.__dict__["period_cycle"] = period_cycle
            __props__.__dict__["queue_capacity"] = queue_capacity
            __props__.__dict__["renewal_duration"] = renewal_duration
            __props__.__dict__["renewal_duration_unit"] = renewal_duration_unit
            __props__.__dict__["renewal_status"] = renewal_status
            __props__.__dict__["serverless_charge_type"] = serverless_charge_type
            __props__.__dict__["storage_size"] = storage_size
            __props__.__dict__["support_eip"] = support_eip
            __props__.__dict__["support_tracing"] = support_tracing
            __props__.__dict__["tracing_storage_time"] = tracing_storage_time
            __props__.__dict__["create_time"] = None
            __props__.__dict__["status"] = None
        super(Instance, __self__).__init__(
            'alicloud:amqp/instance:Instance',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            auto_renew: Optional[pulumi.Input[bool]] = None,
            create_time: Optional[pulumi.Input[int]] = None,
            instance_name: Optional[pulumi.Input[str]] = None,
            instance_type: Optional[pulumi.Input[str]] = None,
            max_connections: Optional[pulumi.Input[int]] = None,
            max_eip_tps: Optional[pulumi.Input[str]] = None,
            max_tps: Optional[pulumi.Input[str]] = None,
            modify_type: Optional[pulumi.Input[str]] = None,
            payment_type: Optional[pulumi.Input[str]] = None,
            period: Optional[pulumi.Input[int]] = None,
            period_cycle: Optional[pulumi.Input[str]] = None,
            queue_capacity: Optional[pulumi.Input[str]] = None,
            renewal_duration: Optional[pulumi.Input[int]] = None,
            renewal_duration_unit: Optional[pulumi.Input[str]] = None,
            renewal_status: Optional[pulumi.Input[str]] = None,
            serverless_charge_type: Optional[pulumi.Input[str]] = None,
            status: Optional[pulumi.Input[str]] = None,
            storage_size: Optional[pulumi.Input[str]] = None,
            support_eip: Optional[pulumi.Input[bool]] = None,
            support_tracing: Optional[pulumi.Input[bool]] = None,
            tracing_storage_time: Optional[pulumi.Input[int]] = None) -> 'Instance':
        """
        Get an existing Instance resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] auto_renew: Renewal method. Automatic renewal: true; Manual renewal: false. When RenewalStatus has a value, the value of RenewalStatus shall prevail.
        :param pulumi.Input[int] create_time: OrderCreateTime.
        :param pulumi.Input[str] instance_name: The instance name.
        :param pulumi.Input[str] instance_type: Instance type. Valid values are as follows:  professional: professional Edition enterprise: enterprise Edition vip: Platinum Edition.
        :param pulumi.Input[int] max_connections: The maximum number of connections, according to the value given on the purchase page of the cloud message queue RabbitMQ version console.
        :param pulumi.Input[str] max_eip_tps: Peak TPS traffic of the public network, which must be a multiple of 128, unit: times per second.
        :param pulumi.Input[str] max_tps: Configure the private network TPS traffic peak, please set the value according to the cloud message queue RabbitMQ version of the console purchase page given.
        :param pulumi.Input[str] modify_type: This parameter must be provided while you change the instance specification. Type of instance lifting and lowering:
               - Upgrade: Upgrade
               - Downgrade: Downgrading.
        :param pulumi.Input[str] payment_type: The Payment type. Valid value: Subscription: prepaid. PayAsYouGo: Post-paid.
        :param pulumi.Input[int] period: Prepayment cycle, unit: periodCycle.  This parameter is valid when PaymentType is set to Subscription.
        :param pulumi.Input[str] period_cycle: Prepaid cycle units. Value: Month. Year: Year.
        :param pulumi.Input[str] queue_capacity: Configure the maximum number of queues. The value range is as follows:  Professional version:[50,1000], minimum modification step size is 5  Enterprise Edition:[200,6000], minimum modification step size is 100  Platinum version:[10000,80000], minimum modification step size is 100.
        :param pulumi.Input[int] renewal_duration: The number of automatic renewal cycles.
        :param pulumi.Input[str] renewal_duration_unit: Auto-Renewal Cycle Unit Values Include: Month: Month. Year: Years.
        :param pulumi.Input[str] renewal_status: The renewal status. Value: AutoRenewal: automatic renewal. ManualRenewal: manual renewal. NotRenewal: no renewal.
        :param pulumi.Input[str] serverless_charge_type: The billing type of the serverless instance. Value: onDemand.
        :param pulumi.Input[str] status: The status of the resource.
        :param pulumi.Input[str] storage_size: Configure the message storage space. Unit: GB. The value is as follows:  Professional Edition and Enterprise Edition: Fixed to 0. Description A value of 0 indicates that the Professional Edition and Enterprise Edition instances do not charge storage fees, but do not have storage space. Platinum version example: m × 100, where the value range of m is [7,28].
        :param pulumi.Input[bool] support_eip: Whether to support public network.
        :param pulumi.Input[bool] support_tracing: Whether to activate the message trace function. The values are as follows:  true: Enable message trace function false: message trace function is not enabled Description The Platinum Edition instance provides the 15-day message trace function free of charge. The trace function can only be enabled and the trace storage duration can only be set to 15 days. For instances of other specifications, you can enable or disable the trace function.
        :param pulumi.Input[int] tracing_storage_time: Configure the storage duration of message traces. Unit: Days. The value is as follows:  3:3 days 7:7 days 15:15 days This parameter is valid when SupportTracing is true.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _InstanceState.__new__(_InstanceState)

        __props__.__dict__["auto_renew"] = auto_renew
        __props__.__dict__["create_time"] = create_time
        __props__.__dict__["instance_name"] = instance_name
        __props__.__dict__["instance_type"] = instance_type
        __props__.__dict__["max_connections"] = max_connections
        __props__.__dict__["max_eip_tps"] = max_eip_tps
        __props__.__dict__["max_tps"] = max_tps
        __props__.__dict__["modify_type"] = modify_type
        __props__.__dict__["payment_type"] = payment_type
        __props__.__dict__["period"] = period
        __props__.__dict__["period_cycle"] = period_cycle
        __props__.__dict__["queue_capacity"] = queue_capacity
        __props__.__dict__["renewal_duration"] = renewal_duration
        __props__.__dict__["renewal_duration_unit"] = renewal_duration_unit
        __props__.__dict__["renewal_status"] = renewal_status
        __props__.__dict__["serverless_charge_type"] = serverless_charge_type
        __props__.__dict__["status"] = status
        __props__.__dict__["storage_size"] = storage_size
        __props__.__dict__["support_eip"] = support_eip
        __props__.__dict__["support_tracing"] = support_tracing
        __props__.__dict__["tracing_storage_time"] = tracing_storage_time
        return Instance(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="autoRenew")
    def auto_renew(self) -> pulumi.Output[Optional[bool]]:
        """
        Renewal method. Automatic renewal: true; Manual renewal: false. When RenewalStatus has a value, the value of RenewalStatus shall prevail.
        """
        return pulumi.get(self, "auto_renew")

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> pulumi.Output[int]:
        """
        OrderCreateTime.
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter(name="instanceName")
    def instance_name(self) -> pulumi.Output[str]:
        """
        The instance name.
        """
        return pulumi.get(self, "instance_name")

    @property
    @pulumi.getter(name="instanceType")
    def instance_type(self) -> pulumi.Output[str]:
        """
        Instance type. Valid values are as follows:  professional: professional Edition enterprise: enterprise Edition vip: Platinum Edition.
        """
        return pulumi.get(self, "instance_type")

    @property
    @pulumi.getter(name="maxConnections")
    def max_connections(self) -> pulumi.Output[int]:
        """
        The maximum number of connections, according to the value given on the purchase page of the cloud message queue RabbitMQ version console.
        """
        return pulumi.get(self, "max_connections")

    @property
    @pulumi.getter(name="maxEipTps")
    def max_eip_tps(self) -> pulumi.Output[str]:
        """
        Peak TPS traffic of the public network, which must be a multiple of 128, unit: times per second.
        """
        return pulumi.get(self, "max_eip_tps")

    @property
    @pulumi.getter(name="maxTps")
    def max_tps(self) -> pulumi.Output[str]:
        """
        Configure the private network TPS traffic peak, please set the value according to the cloud message queue RabbitMQ version of the console purchase page given.
        """
        return pulumi.get(self, "max_tps")

    @property
    @pulumi.getter(name="modifyType")
    def modify_type(self) -> pulumi.Output[Optional[str]]:
        """
        This parameter must be provided while you change the instance specification. Type of instance lifting and lowering:
        - Upgrade: Upgrade
        - Downgrade: Downgrading.
        """
        return pulumi.get(self, "modify_type")

    @property
    @pulumi.getter(name="paymentType")
    def payment_type(self) -> pulumi.Output[str]:
        """
        The Payment type. Valid value: Subscription: prepaid. PayAsYouGo: Post-paid.
        """
        return pulumi.get(self, "payment_type")

    @property
    @pulumi.getter
    def period(self) -> pulumi.Output[Optional[int]]:
        """
        Prepayment cycle, unit: periodCycle.  This parameter is valid when PaymentType is set to Subscription.
        """
        return pulumi.get(self, "period")

    @property
    @pulumi.getter(name="periodCycle")
    def period_cycle(self) -> pulumi.Output[Optional[str]]:
        """
        Prepaid cycle units. Value: Month. Year: Year.
        """
        return pulumi.get(self, "period_cycle")

    @property
    @pulumi.getter(name="queueCapacity")
    def queue_capacity(self) -> pulumi.Output[str]:
        """
        Configure the maximum number of queues. The value range is as follows:  Professional version:[50,1000], minimum modification step size is 5  Enterprise Edition:[200,6000], minimum modification step size is 100  Platinum version:[10000,80000], minimum modification step size is 100.
        """
        return pulumi.get(self, "queue_capacity")

    @property
    @pulumi.getter(name="renewalDuration")
    def renewal_duration(self) -> pulumi.Output[int]:
        """
        The number of automatic renewal cycles.
        """
        return pulumi.get(self, "renewal_duration")

    @property
    @pulumi.getter(name="renewalDurationUnit")
    def renewal_duration_unit(self) -> pulumi.Output[str]:
        """
        Auto-Renewal Cycle Unit Values Include: Month: Month. Year: Years.
        """
        return pulumi.get(self, "renewal_duration_unit")

    @property
    @pulumi.getter(name="renewalStatus")
    def renewal_status(self) -> pulumi.Output[str]:
        """
        The renewal status. Value: AutoRenewal: automatic renewal. ManualRenewal: manual renewal. NotRenewal: no renewal.
        """
        return pulumi.get(self, "renewal_status")

    @property
    @pulumi.getter(name="serverlessChargeType")
    def serverless_charge_type(self) -> pulumi.Output[Optional[str]]:
        """
        The billing type of the serverless instance. Value: onDemand.
        """
        return pulumi.get(self, "serverless_charge_type")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[str]:
        """
        The status of the resource.
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="storageSize")
    def storage_size(self) -> pulumi.Output[str]:
        """
        Configure the message storage space. Unit: GB. The value is as follows:  Professional Edition and Enterprise Edition: Fixed to 0. Description A value of 0 indicates that the Professional Edition and Enterprise Edition instances do not charge storage fees, but do not have storage space. Platinum version example: m × 100, where the value range of m is [7,28].
        """
        return pulumi.get(self, "storage_size")

    @property
    @pulumi.getter(name="supportEip")
    def support_eip(self) -> pulumi.Output[Optional[bool]]:
        """
        Whether to support public network.
        """
        return pulumi.get(self, "support_eip")

    @property
    @pulumi.getter(name="supportTracing")
    def support_tracing(self) -> pulumi.Output[bool]:
        """
        Whether to activate the message trace function. The values are as follows:  true: Enable message trace function false: message trace function is not enabled Description The Platinum Edition instance provides the 15-day message trace function free of charge. The trace function can only be enabled and the trace storage duration can only be set to 15 days. For instances of other specifications, you can enable or disable the trace function.
        """
        return pulumi.get(self, "support_tracing")

    @property
    @pulumi.getter(name="tracingStorageTime")
    def tracing_storage_time(self) -> pulumi.Output[int]:
        """
        Configure the storage duration of message traces. Unit: Days. The value is as follows:  3:3 days 7:7 days 15:15 days This parameter is valid when SupportTracing is true.
        """
        return pulumi.get(self, "tracing_storage_time")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetForwardEntriesResult',
    'AwaitableGetForwardEntriesResult',
    'get_forward_entries',
    'get_forward_entries_output',
]

@pulumi.output_type
class GetForwardEntriesResult:
    """
    A collection of values returned by getForwardEntries.
    """
    def __init__(__self__, entries=None, external_ip=None, external_port=None, forward_entry_name=None, forward_table_id=None, id=None, ids=None, internal_ip=None, internal_port=None, ip_protocol=None, name_regex=None, names=None, output_file=None, status=None):
        if entries and not isinstance(entries, list):
            raise TypeError("Expected argument 'entries' to be a list")
        pulumi.set(__self__, "entries", entries)
        if external_ip and not isinstance(external_ip, str):
            raise TypeError("Expected argument 'external_ip' to be a str")
        pulumi.set(__self__, "external_ip", external_ip)
        if external_port and not isinstance(external_port, str):
            raise TypeError("Expected argument 'external_port' to be a str")
        pulumi.set(__self__, "external_port", external_port)
        if forward_entry_name and not isinstance(forward_entry_name, str):
            raise TypeError("Expected argument 'forward_entry_name' to be a str")
        pulumi.set(__self__, "forward_entry_name", forward_entry_name)
        if forward_table_id and not isinstance(forward_table_id, str):
            raise TypeError("Expected argument 'forward_table_id' to be a str")
        pulumi.set(__self__, "forward_table_id", forward_table_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)
        if internal_ip and not isinstance(internal_ip, str):
            raise TypeError("Expected argument 'internal_ip' to be a str")
        pulumi.set(__self__, "internal_ip", internal_ip)
        if internal_port and not isinstance(internal_port, str):
            raise TypeError("Expected argument 'internal_port' to be a str")
        pulumi.set(__self__, "internal_port", internal_port)
        if ip_protocol and not isinstance(ip_protocol, str):
            raise TypeError("Expected argument 'ip_protocol' to be a str")
        pulumi.set(__self__, "ip_protocol", ip_protocol)
        if name_regex and not isinstance(name_regex, str):
            raise TypeError("Expected argument 'name_regex' to be a str")
        pulumi.set(__self__, "name_regex", name_regex)
        if names and not isinstance(names, list):
            raise TypeError("Expected argument 'names' to be a list")
        pulumi.set(__self__, "names", names)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter
    def entries(self) -> Sequence['outputs.GetForwardEntriesEntryResult']:
        """
        A list of Forward Entries. Each element contains the following attributes:
        """
        return pulumi.get(self, "entries")

    @property
    @pulumi.getter(name="externalIp")
    def external_ip(self) -> Optional[str]:
        """
        The public IP address.
        """
        return pulumi.get(self, "external_ip")

    @property
    @pulumi.getter(name="externalPort")
    def external_port(self) -> Optional[str]:
        """
        The public port.
        """
        return pulumi.get(self, "external_port")

    @property
    @pulumi.getter(name="forwardEntryName")
    def forward_entry_name(self) -> Optional[str]:
        """
        The name of forward entry.
        """
        return pulumi.get(self, "forward_entry_name")

    @property
    @pulumi.getter(name="forwardTableId")
    def forward_table_id(self) -> str:
        return pulumi.get(self, "forward_table_id")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ids(self) -> Sequence[str]:
        """
        A list of Forward Entries IDs.
        """
        return pulumi.get(self, "ids")

    @property
    @pulumi.getter(name="internalIp")
    def internal_ip(self) -> Optional[str]:
        """
        The private IP address.
        """
        return pulumi.get(self, "internal_ip")

    @property
    @pulumi.getter(name="internalPort")
    def internal_port(self) -> Optional[str]:
        """
        The private port.
        """
        return pulumi.get(self, "internal_port")

    @property
    @pulumi.getter(name="ipProtocol")
    def ip_protocol(self) -> Optional[str]:
        """
        The protocol type.
        """
        return pulumi.get(self, "ip_protocol")

    @property
    @pulumi.getter(name="nameRegex")
    def name_regex(self) -> Optional[str]:
        return pulumi.get(self, "name_regex")

    @property
    @pulumi.getter
    def names(self) -> Sequence[str]:
        """
        A list of Forward Entries names.
        """
        return pulumi.get(self, "names")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[str]:
        return pulumi.get(self, "output_file")

    @property
    @pulumi.getter
    def status(self) -> Optional[str]:
        """
        The status of forward entry.
        """
        return pulumi.get(self, "status")


class AwaitableGetForwardEntriesResult(GetForwardEntriesResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetForwardEntriesResult(
            entries=self.entries,
            external_ip=self.external_ip,
            external_port=self.external_port,
            forward_entry_name=self.forward_entry_name,
            forward_table_id=self.forward_table_id,
            id=self.id,
            ids=self.ids,
            internal_ip=self.internal_ip,
            internal_port=self.internal_port,
            ip_protocol=self.ip_protocol,
            name_regex=self.name_regex,
            names=self.names,
            output_file=self.output_file,
            status=self.status)


def get_forward_entries(external_ip: Optional[str] = None,
                        external_port: Optional[str] = None,
                        forward_entry_name: Optional[str] = None,
                        forward_table_id: Optional[str] = None,
                        ids: Optional[Sequence[str]] = None,
                        internal_ip: Optional[str] = None,
                        internal_port: Optional[str] = None,
                        ip_protocol: Optional[str] = None,
                        name_regex: Optional[str] = None,
                        output_file: Optional[str] = None,
                        status: Optional[str] = None,
                        opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetForwardEntriesResult:
    """
    This data source provides a list of Forward Entries owned by an Alibaba Cloud account.

    > **NOTE:** Available in 1.37.0+.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    config = pulumi.Config()
    name = config.get("name")
    if name is None:
        name = "forward-entry-config-example-name"
    default = alicloud.get_zones(available_resource_creation="VSwitch")
    default_network = alicloud.vpc.Network("default",
        vpc_name=name,
        cidr_block="172.16.0.0/12")
    default_switch = alicloud.vpc.Switch("default",
        vpc_id=default_network.id,
        cidr_block="172.16.0.0/21",
        zone_id=default.zones[0].id,
        vswitch_name=name)
    default_nat_gateway = alicloud.vpc.NatGateway("default",
        vpc_id=default_network.id,
        internet_charge_type="PayByLcu",
        nat_gateway_name=name,
        nat_type="Enhanced",
        vswitch_id=default_switch.id)
    default_eip_address = alicloud.ecs.EipAddress("default", address_name=name)
    default_eip_association = alicloud.ecs.EipAssociation("default",
        allocation_id=default_eip_address.id,
        instance_id=default_nat_gateway.id)
    default_forward_entry = alicloud.vpc.ForwardEntry("default",
        forward_table_id=default_nat_gateway.forward_table_ids,
        external_ip=default_eip_address.ip_address,
        external_port="80",
        ip_protocol="tcp",
        internal_ip="172.16.0.3",
        internal_port="8080")
    default_get_forward_entries = alicloud.vpc.get_forward_entries_output(forward_table_id=default_forward_entry.forward_table_id)
    ```


    :param str external_ip: The public IP address.
    :param str external_port: The public port.
    :param str forward_entry_name: The name of forward entry.
    :param str forward_table_id: The ID of the Forward table.
    :param Sequence[str] ids: A list of Forward Entries IDs.
    :param str internal_ip: The private IP address.
    :param str internal_port: The internal port.
    :param str ip_protocol: The ip protocol. Valid values: `any`,`tcp` and `udp`.
    :param str name_regex: A regex string to filter results by forward entry name.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param str status: The status of farward entry. Valid value `Available`, `Deleting` and `Pending`.
    """
    __args__ = dict()
    __args__['externalIp'] = external_ip
    __args__['externalPort'] = external_port
    __args__['forwardEntryName'] = forward_entry_name
    __args__['forwardTableId'] = forward_table_id
    __args__['ids'] = ids
    __args__['internalIp'] = internal_ip
    __args__['internalPort'] = internal_port
    __args__['ipProtocol'] = ip_protocol
    __args__['nameRegex'] = name_regex
    __args__['outputFile'] = output_file
    __args__['status'] = status
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:vpc/getForwardEntries:getForwardEntries', __args__, opts=opts, typ=GetForwardEntriesResult).value

    return AwaitableGetForwardEntriesResult(
        entries=pulumi.get(__ret__, 'entries'),
        external_ip=pulumi.get(__ret__, 'external_ip'),
        external_port=pulumi.get(__ret__, 'external_port'),
        forward_entry_name=pulumi.get(__ret__, 'forward_entry_name'),
        forward_table_id=pulumi.get(__ret__, 'forward_table_id'),
        id=pulumi.get(__ret__, 'id'),
        ids=pulumi.get(__ret__, 'ids'),
        internal_ip=pulumi.get(__ret__, 'internal_ip'),
        internal_port=pulumi.get(__ret__, 'internal_port'),
        ip_protocol=pulumi.get(__ret__, 'ip_protocol'),
        name_regex=pulumi.get(__ret__, 'name_regex'),
        names=pulumi.get(__ret__, 'names'),
        output_file=pulumi.get(__ret__, 'output_file'),
        status=pulumi.get(__ret__, 'status'))
def get_forward_entries_output(external_ip: Optional[pulumi.Input[Optional[str]]] = None,
                               external_port: Optional[pulumi.Input[Optional[str]]] = None,
                               forward_entry_name: Optional[pulumi.Input[Optional[str]]] = None,
                               forward_table_id: Optional[pulumi.Input[str]] = None,
                               ids: Optional[pulumi.Input[Optional[Sequence[str]]]] = None,
                               internal_ip: Optional[pulumi.Input[Optional[str]]] = None,
                               internal_port: Optional[pulumi.Input[Optional[str]]] = None,
                               ip_protocol: Optional[pulumi.Input[Optional[str]]] = None,
                               name_regex: Optional[pulumi.Input[Optional[str]]] = None,
                               output_file: Optional[pulumi.Input[Optional[str]]] = None,
                               status: Optional[pulumi.Input[Optional[str]]] = None,
                               opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetForwardEntriesResult]:
    """
    This data source provides a list of Forward Entries owned by an Alibaba Cloud account.

    > **NOTE:** Available in 1.37.0+.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    config = pulumi.Config()
    name = config.get("name")
    if name is None:
        name = "forward-entry-config-example-name"
    default = alicloud.get_zones(available_resource_creation="VSwitch")
    default_network = alicloud.vpc.Network("default",
        vpc_name=name,
        cidr_block="172.16.0.0/12")
    default_switch = alicloud.vpc.Switch("default",
        vpc_id=default_network.id,
        cidr_block="172.16.0.0/21",
        zone_id=default.zones[0].id,
        vswitch_name=name)
    default_nat_gateway = alicloud.vpc.NatGateway("default",
        vpc_id=default_network.id,
        internet_charge_type="PayByLcu",
        nat_gateway_name=name,
        nat_type="Enhanced",
        vswitch_id=default_switch.id)
    default_eip_address = alicloud.ecs.EipAddress("default", address_name=name)
    default_eip_association = alicloud.ecs.EipAssociation("default",
        allocation_id=default_eip_address.id,
        instance_id=default_nat_gateway.id)
    default_forward_entry = alicloud.vpc.ForwardEntry("default",
        forward_table_id=default_nat_gateway.forward_table_ids,
        external_ip=default_eip_address.ip_address,
        external_port="80",
        ip_protocol="tcp",
        internal_ip="172.16.0.3",
        internal_port="8080")
    default_get_forward_entries = alicloud.vpc.get_forward_entries_output(forward_table_id=default_forward_entry.forward_table_id)
    ```


    :param str external_ip: The public IP address.
    :param str external_port: The public port.
    :param str forward_entry_name: The name of forward entry.
    :param str forward_table_id: The ID of the Forward table.
    :param Sequence[str] ids: A list of Forward Entries IDs.
    :param str internal_ip: The private IP address.
    :param str internal_port: The internal port.
    :param str ip_protocol: The ip protocol. Valid values: `any`,`tcp` and `udp`.
    :param str name_regex: A regex string to filter results by forward entry name.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param str status: The status of farward entry. Valid value `Available`, `Deleting` and `Pending`.
    """
    __args__ = dict()
    __args__['externalIp'] = external_ip
    __args__['externalPort'] = external_port
    __args__['forwardEntryName'] = forward_entry_name
    __args__['forwardTableId'] = forward_table_id
    __args__['ids'] = ids
    __args__['internalIp'] = internal_ip
    __args__['internalPort'] = internal_port
    __args__['ipProtocol'] = ip_protocol
    __args__['nameRegex'] = name_regex
    __args__['outputFile'] = output_file
    __args__['status'] = status
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('alicloud:vpc/getForwardEntries:getForwardEntries', __args__, opts=opts, typ=GetForwardEntriesResult)
    return __ret__.apply(lambda __response__: GetForwardEntriesResult(
        entries=pulumi.get(__response__, 'entries'),
        external_ip=pulumi.get(__response__, 'external_ip'),
        external_port=pulumi.get(__response__, 'external_port'),
        forward_entry_name=pulumi.get(__response__, 'forward_entry_name'),
        forward_table_id=pulumi.get(__response__, 'forward_table_id'),
        id=pulumi.get(__response__, 'id'),
        ids=pulumi.get(__response__, 'ids'),
        internal_ip=pulumi.get(__response__, 'internal_ip'),
        internal_port=pulumi.get(__response__, 'internal_port'),
        ip_protocol=pulumi.get(__response__, 'ip_protocol'),
        name_regex=pulumi.get(__response__, 'name_regex'),
        names=pulumi.get(__response__, 'names'),
        output_file=pulumi.get(__response__, 'output_file'),
        status=pulumi.get(__response__, 'status')))
